library(ggplot2)
library(reshape2)
library(plyr)
library(akima)

ll <- scale_colour_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white")
lll <- scale_fill_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white")

stellopts <- theme(legend.text= element_text(size = 14),legend.title = element_text(size = 14, face = 'bold'),axis.title.x = element_text(size = 14), axis.title.y = element_text(size = 14, angle =90),axis.text.x = element_text(size =14), axis.text.y = element_text(size = 14), panel.grid.minor = element_blank(), panel.grid.major = element_blank())

#function for merging physical environment and image data
nearphys <- function(x,y) {
  n <- length(x) #x will be the biological data
  phystime <- vector(length = n)
  for(i in 1:n) {
    phystime[i] <- which.min(abs(x[i]-y))
  }
  return(phystime)
}


julianmakerslice <- function(hr, minu, sec, slice) {
  julian <- (hr/24)+(minu/(24*60))+(sec/(24*60*60))+(((slice/430)*25.165)/(24*60*60))
  return(julian)
}

#function converting a list to a data frame - needed for interpolation
list2frame <- function(X, names=c("x", "y", "z"))
  #
  # Turn a list with three components (suitable for persp and the like) into a data.frame with columns x, y, z, suitable for ggplot
  #
  # X   list with components x, y, and z
{
  if (!is.list(X)) {
    stop("Need a list")
  }
  
  if ( is.null(names(X)) & length(X) == 3 ) {
    # if the list has no names and the right size, assume components are in order and rename them
    warning("Assuming list components are in the order: ", paste(names, collapse=","))
    names(X) <- names
  } else if ( !all(names %in% names(X)) & length(X) == 3 ) {
    # if the list names do not match but it has the right size, assume components are in order and rename them
    warning("Assuming components ", paste(names(X), collapse=","), " are in fact ", paste(names, collapse=","))
    names(X) <- names
  } else if (all(names %in% names(X))) {
    # if all names are in the list, extract the corresponding components
    X <- X[names]
  } else {
    stop("Cannot find coordinates and values in this list. Check names")
  }
  
  # convert into data.frame
  suppressPackageStartupMessages(require("reshape2"))
  out = melt(X$z,varnames=c("x","y"))
  out$x = X$x[out$x]
  out$y = X$y[out$y]
  out = rename(out,c(value="z"))
  
  return(out)
}


setwd("d:/")
load("205_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dor1 <- subset(dor, totdol > 0)

ggplot(dor1, aes(Long, -as.numeric(Depth), size = tunicate_doliolid))+geom_point()

ggplot()+geom_point(data = dor1, aes(Long, -as.numeric(Depth), size = tunicate_doliolid))+
  geom_point(data = dor1, aes(Long, -(as.numeric(Depth)+as.numeric(Altitude))), colour = "red")

ggplot(dor1, aes(Long, -as.numeric(Depth), size = tunicate_doliolid_with_nurse))+geom_point()
ggplot(dor1, aes(Long, -as.numeric(Depth), size = tunicate_doliolid_budding))+geom_point()
ggplot(dor1, aes(Long, Lat, size = tunicate_doliolid))+geom_point()

#CA 2018
load("213_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dca1 <- subset(dor, totdol > 0)

ggplot(dor1, aes(Long, -as.numeric(Depth), size = totdol))+geom_point()

#Oregon 2019
load("425_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dor2 <- subset(dor, totdol > 0)

ggplot(dor1, aes(Long, -as.numeric(Depth), size = totdol))+geom_point()

#CA 2019
load("401_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dca2 <- subset(dor, totdol > 0)

ggplot(dor1, aes(Long, -as.numeric(Depth), size = totdol))+geom_point()

#compare oregon salinities
dor1$year <- "2018"
dor2$year <- "2019"

#make a distance for each transect
head(dor1)
tail(dor1)

dort <- rbind(dor1, dor2)
ggplot(dort, aes(year, as.numeric(Salinity)))+geom_boxplot()
ggplot(dort, aes(year, as.numeric(Temp)))+geom_boxplot() #similar between years
ggplot(dort, aes(year, as.numeric(Fluoro)))+geom_boxplot()
ggplot(dort, aes(year, as.numeric(Oxygen)))+geom_boxplot() #similar between years
ggplot(dort, aes(year, -as.numeric(Depth)))+geom_boxplot() #similar and shallow between years
dort$Location <- "Oregon"

#compare CA salinities
dca1$year <- "2018"
dca2$year <- "2019"
dcat <- rbind(dca1, dca2)
ggplot(dcat, aes(year, as.numeric(Salinity)))+geom_boxplot()
ggplot(dcat, aes(year, as.numeric(Temp)))+geom_boxplot() #similar between years
ggplot(dcat, aes(year, as.numeric(Fluoro)))+geom_boxplot()
ggplot(dcat, aes(year, as.numeric(Oxygen)))+geom_boxplot() #similar between years
ggplot(dcat, aes(year, -as.numeric(Depth)))+geom_boxplot() #similar between years but deeper than OR
dcat$Location <- "California"

dcaor <- rbind(dort, dcat)
ggplot(dcaor, aes(Location, as.numeric(Salinity), fill = year))+geom_boxplot()

ggplot(dcaor, aes(year, as.numeric(Salinity)))+geom_boxplot()+facet_wrap(~Location)

##Read in the nGOM data##
dgu <- read.csv("726dolenv3cats.csv", header = TRUE)
#get salinity, temp, fluor
dgs <- dgu[,c(11, 15:17, 26)]
dgs$year <- "2016"
dgs$Location <- "Gulf of Mexico"

#get the columns from dcaor
head(dcaor)
dco <- dcaor[,c(38, 34, 33, 15, 35, 39, 40)]
head(dco)
colnames(dco) <- colnames(dgs)

dgsc <- rbind(dgs, dco)
ggplot(dgsc, aes(Location, as.numeric(salinity), fill = year))+geom_boxplot()
ggplot(dgsc, aes(Location, as.numeric(temp), fill = year))+geom_boxplot()
ggplot(dgsc, aes(Location, as.numeric(fluor), fill = year))+geom_boxplot()
ggplot(dgsc, aes(Location, -as.numeric(depth), fill = year))+geom_boxplot()

ggplot(dgsc, aes(as.numeric(temp), as.numeric(salinity), colour = Location, shape = year))+geom_point(alpha = 0.3, size = 2)+
  labs(x = expression(paste("Temp. (", degree~C,")")), y = "Salinity")+theme_bw()
#ggsave("TSDolEnv3.png", dpi = 300)

#look at the nurse vs. gono vs. phoro
dgn <- subset(dgs, ID2 == "Nurse")
dgg <- subset(dgs, ID2 == "Gonozooid")
dpp <- subset(dgs, ID2 == "Phorozooid")

head(dcaor)
dcnn <- subset(dcaor, tunicate_doliolid_with_nurse > 0)
dcgg <- subset(dcaor, tunicate_doliolid > 0)
dcgp <- subset(dcaor, tunicate_doliolid_budding > 0)

dcn2 <- dcnn[,c(34, 33, 15, 35, 39, 40)]
nn2 <- rep("Nurse", times = nrow(dcn2))
dcn22 <- cbind(nn2, dcn2)
colnames(dcn22) <- colnames(dgn)

dcg2<- dcgg[,c(34, 33, 15, 35, 39, 40)]
gg2 <- rep("Gonozooid", times = nrow(dcg2))
dcg22 <- cbind(gg2, dcg2)
colnames(dcg22) <- colnames(dgn)

dcp2<- dcgp[,c(34, 33, 15, 35, 39, 40)]
pp2 <- rep("Phorozooid", times = nrow(dcp2))
dcp22 <- cbind(pp2, dcp2)
colnames(dcp22) <- colnames(dgn)

dcas <- rbind(dcg22, dcn22, dcp22, dgn, dgg, dpp)

ggplot(dcas, aes(Location, as.numeric(salinity), fill = year))+geom_boxplot()+facet_wrap(~ID2)

ggplot(dcas, aes(Location, -as.numeric(depth), fill = year))+geom_boxplot()+facet_wrap(~ID2)

ggplot(dcas, aes(Location, -as.numeric(depth), fill = ID2))+geom_boxplot()

ggplot(dcas, aes(Location, as.numeric(fluor), fill = ID2))+geom_boxplot()

ggplot(dcas, aes(Location, as.numeric(temp), fill = ID2))+geom_boxplot()

ggplot(dcas, aes(as.numeric(temp), as.numeric(salinity), colour = Location))+geom_point(alpha = 0.3)+facet_wrap(~ID2)+
  theme_bw()

ggplot(dcas, aes(as.numeric(temp), as.numeric(salinity), colour = fluor, shape = Location))+geom_point(size = 2, alpha = 0.3)+facet_wrap(~ID2)+
  theme_bw()+ll

nopts <- theme(legend.text= element_text(size = 14),legend.title = element_text(size = 14, face = 'bold'),axis.title.x = element_text(size = 14), axis.title.y = element_text(size = 14, angle =90),axis.text.x = element_text(size =14), axis.text.y = element_text(size = 14))

ggplot(dcas, aes(as.numeric(temp), as.numeric(salinity), colour = fluor))+geom_point(size = 2, alpha = 0.3)+facet_grid(Location~ID2)+
  theme_bw()+ll+labs(x = expression(paste("Temp. (", degree~C,")")), y = "Salinity", colour = "Chl-a")+nopts+
  theme(strip.text.y = element_text(size = 14), strip.text.x = element_text(size = 14))
#ggsave("DolStageTSbyRegion.png", dpi = 400)

###############Concorde data ECORR####################
setwd("d:/PTS03_089_ECORR")
dols <- read.csv("PTS03_089_T030_ECORR_ft_ess_tunicate_doliolid.csv", header = TRUE)
nur <- read.csv("PTS03_089_T030_ECORR_ft_ess_tunicate_doliolid_nurse.csv", header = TRUE)
bud <- read.csv("PTS03_089_T030_ECORR_ft_ess_tunicate_doliolid_juvenile_buds.csv", header = TRUE)
head(nur)

ggplot(nur, aes(LATITUDE_DEG, -DEPTH_M))+geom_point()

#rdepth <- round_any()
ggplot(dols, aes(LATITUDE_DEG, -DEPTH_M))+geom_point()

tdol <- rbind(dols, nur, bud)

label <- as.character(tdol$SEGMENT_FILENAME)

jul <- substr(label, 5,23)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 5,6)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 7,8))
sec <- as.numeric(substr(jul, 9,14))
slice <- as.numeric(substr(jul, 17,19))

tdol$njul <- julianmakerslice(hr, minu, sec, slice)

setwd("d:/")
dgu <- read.csv("726dolenv3cats.csv", header = TRUE)
#7 seconds per bin
#That is 0.000081 julian time in 7 seconds

dgu$rjul <-round_any(dgu$julian, 0.000081, ceiling)

manco <- ddply(dgu, .(rjul), summarize, mdepth = mean(depth), pco2 = length(rjul), mlat = mean(lat))
head(manco)

head(tdol)

tdol$rjul <-round_any(tdol$njul, 0.000081, ceiling)
head(tdol)
autco <- ddply(tdol, .(rjul), summarize, mdepth = mean(DEPTH_M), pco = length(rjul), mlat = mean (LATITUDE_DEG))

min(autco$rjul)
min(manco$rjul)
max(manco$rjul)
max(autco$rjul)

comp2 <- subset(autco, rjul > min(manco$rjul) & rjul < max(manco$rjul))
head(autco)
head(manco)

manind <- nearphys(manco$rjul, autco$rjul)
manco$autjul <- autco[manind, 1]
head(manco)
head(autco)
colnames(autco)[1] <- "autjul"
mana <- merge(manco, autco, by = "autjul", all.y = TRUE)
head(mana)
mana[is.na(mana)] <- 0 

ggplot(mana, aes(pco, pco2))+geom_point()+labs(x = "Automated conc.", y = "Manual conc.")+
  geom_smooth(method = "lm", se = FALSE)+theme_bw()
#ggsave("AutoManLinearReg.png", dpi = 300)
ggplot(subset(mana, pco < 270), aes(pco, pco2))+geom_point()+labs(x = "Automated conc.", y = "Manual conc.")+
  geom_smooth(method = "lm", se = FALSE)+theme_bw()
cor(mana$pco, mana$pco2, method = "spearman")


subset(autco, pco >400)
subset(mana, pco > 400)
#huge number of doliolids at 12:47:36 - disagrees with manual analysis by a lot
#write.csv(mana, file = "AutoManualAnalysisECORR.csv", row.names = FALSE)


#now look at only the nurses
manco2 <- ddply(subset(dgu, ID2 == "Nurse"), .(rjul), summarize, mdepth = mean(depth), pco2 = length(rjul), mlat = mean(lat))
head(manco2)

autco2 <- ddply(subset(tdol, PREDICTED_GROUP == "tunicate_doliolid_nurse"), .(rjul), summarize, mdepth = mean(DEPTH_M), pco = length(rjul), mlat = mean (LATITUDE_DEG))
head(autco2)

head(autco2)
head(manco2)

manind <- nearphys(manco2$rjul, autco2$rjul)
manco2$autjul <- autco2[manind, 1]
head(manco2)
head(autco2)
colnames(autco2)[1] <- "autjul"
mana2 <- merge(manco2, autco2, by = "autjul", all.y = TRUE)
head(mana2)
mana2[is.na(mana2)] <- 0 

ggplot(mana2, aes(pco, pco2))+geom_point()+labs(x = "Automated conc.", y = "Manual conc.")+
  geom_smooth(method = "lm", se = FALSE)+theme_bw()
#ggsave("AutovsManualNurseOnly.png", dpi = 300)

cor(mana2$pco, mana2$pco2, method = "spearman")
cor(mana2$pco, mana2$pco2, method = "pearson")
head(mana2)

mana2$difco <- mana2$pco2-mana2$pco

ggplot(subset(mana2, mlat.x > 20), aes(mlat.x, -mdepth.x, fill = difco))+geom_point(pch = 21, colour = "black", size = 3)+
  scale_fill_gradientn(colours = c("blue", "white", "red"))+theme_bw()

#plot the abundances of nurses from manual
head(dgu)

nursm <- ddply(subset(dgu, ID2 == "Nurse"), .(rjul), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat))

ggplot(nursm, aes(mlat, -mdepth, size = pco2))+geom_point()

#merge the abundances of total doliolids to physical data using the same method as dolenv
setwd("d:/")
phys <- read.csv("20160726physical.csv", header = T, skip = 4)
head(phys)

#change the column names to simple words
colnames(phys) <- c("julian", "utc", "timestamp", "alt", "temp", "depth", "fluor", "fvel", "heading", "o2", "o2volts", 
                    "par", "parvolts", "pitch", "roll", "salinity", "lat", "lon", "vertvel", "altok")

#take physical and create a mean for each rdist
phys$secs <- phys$julian*(24*60*60) 
phys$hdist <- (phys$secs*2.5)-(min(phys$secs*2.5)) 
phys$rdist <- round_any(phys$hdist, 17, ceiling)

bioenv <- nearphys(tdol$njul, phys$julian)

nearjul <- phys[bioenv,1]
tdol <- cbind(nearjul, tdol)
colnames(phys)[1] <- "nearjul"

newfr <- merge(tdol, phys, by = "nearjul", all.x = TRUE)
head(newfr)
tail(newfr)
#write.csv(newfr, "newphysautodolmerged.csv", row.names = FALSE)
newfr <- read.csv("newphysautodolmerged.csv", header = TRUE) #ECORR 

pp2 <- read.csv("726salinityinterp.csv", header = TRUE)
#pp2 <- read.csv("726tempinterp.csv", header = TRUE)

autdol <- ddply(newfr, .(rjul, PREDICTED_GROUP), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat))
head(autdol)
levels(autdol$PREDICTED_GROUP) <- c("Gonozooid", "Phorozooid", "Nurse")
autdol$PREDICTED_GROUP <- factor(autdol$PREDICTED_GROUP, levels = c("Gonozooid", "Nurse", "Phorozooid"))

ggplot()+geom_tile(data = pp2, aes(dist/1000, -depth, fill = salinity))+
  geom_point(data = autdol, aes(mdist/1000, -mdepth, size = pco2), alpha = 0.3)+
  labs(x = "Distance (km)", y = "Depth (m)", size = expression(paste('Abundance'~'(ind.'~m^{-3},')')), fill = "Salinity")+
  facet_grid(PREDICTED_GROUP~.)+
  theme_bw()+stellopts+lll+theme(strip.text.y = element_text(size =14))
#ggsave("AutoDol726-final.png", dpi = 400)

phys2p <- autdol #data frame with the doliolid counts


# transform the distance to account for the anisotropy - 700 seems best
f <- 700
phys2p$distTr <- phys2p$mdist / f

# new coordinate
n <- 100
xo <- seq(min(phys2p$distTr, na.rm=T), max(phys2p$distTr, na.rm=T), length.out=n*4)
yo <- seq(0, max(phys2p$mdepth, na.rm=T), length.out=n)

ti <- ddply(phys2p, ~PREDICTED_GROUP, function(x) {
  # interpolate
  ti <- interp(x$distTr, x$mdepth, x$pco2, xo=xo, yo=yo, duplicate="mean")
  
  # convert the result to data.frame form
  ti <- list2frame(ti)
  return(ti)
}, .progress="text")
#phys2p <- phys2p[seq(1,nrow(phys2p),2),]
#ti <- interp(phys2p$distTr, phys2p$depth, phys2p$correctTemp, xo=xo, yo=yo, duplicate = "mean")

names(ti) <- c("phase", "dist", "depth", "pco")
ti$dist <- ti$dist * f
colnames(ti)[1] <- "ID2"

ggplot()+geom_tile(data = ti, aes(dist/1000, -depth, fill = pco))+
  geom_contour(data = pp2, aes(dist/1000, -depth, z = salinity), breaks = 30:35, colour = "white", size = 1, alpha = 0.7)+
  facet_grid(ID2~.)+theme_bw()+stellopts+lll+
  labs(x = "Distance (km)", y = "Depth (m)", colour = "Salinity", fill = expression(paste('Conc.'~'(ind.'~m^{-3},')')))+
  theme(strip.text.y = element_text(size = 14))

#Make separate plots because abundances are very different among the doliolid life stages
ggplot()+annotate("rect", xmin = .2, xmax = max(ti$dist, na.rm = TRUE)/1000, ymin = -3, ymax = -.5, fill = "blue")+
  geom_tile(data = subset(ti, ID2 == "Nurse"), aes(dist/1000, -depth, fill = pco))+
  geom_contour(data = pp2, aes(dist/1000, -depth, z = salinity), breaks = 30:36, colour = "white", size = 1, alpha = 0.7)+
  facet_grid(ID2~.)+theme_bw()+stellopts+
  scale_fill_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="blue")+
  labs(x = "Distance (km)", y = "Depth (m)", colour = "Salinity", fill = expression(paste('Conc.'~'(ind.'~m^{-3},')')))+
  theme(strip.text.y = element_text(size = 14))+
  geom_ribbon(data = gwcol, aes(x = rrdist2, ymax = rwcol+3, ymin = -40), alpha = 1, fill = 'white')
#ggsave("NurseInterpAuto.png", dpi = 300, width = 11, height = 3)

ggplot()+annotate("rect", xmin = .2, xmax = max(ti$dist, na.rm = TRUE)/1000, ymin = -3, ymax = -.5, fill = "blue")+
  geom_tile(data = subset(ti, ID2 == "Phorozooid"), aes(dist/1000, -depth, fill = pco))+
  geom_contour(data = pp2, aes(dist/1000, -depth, z = salinity), breaks = 30:36, colour = "white", size = 1, alpha = 0.7)+
  facet_grid(ID2~.)+theme_bw()+stellopts+
  scale_fill_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="blue")+
  labs(x = "Distance (km)", y = "Depth (m)", colour = "Salinity", fill = expression(paste('Conc.'~'(ind.'~m^{-3},')')))+
  theme(strip.text.y = element_text(size = 14))+
  geom_ribbon(data = gwcol, aes(x = rrdist2, ymax = rwcol+3, ymin = -40), alpha = 1, fill = 'white')
#ggsave("PhorozooidInterpAuto.png", dpi = 300, width = 11, height = 3)

ggplot()+annotate("rect", xmin = .2, xmax = max(ti$dist, na.rm = TRUE)/1000, ymin = -3, ymax = -.5, fill = "blue")+
  geom_tile(data = subset(ti, ID2 == "Gonozooid"), aes(dist/1000, -depth, fill = pco))+
  geom_contour(data = pp2, aes(dist/1000, -depth, z = salinity), breaks = 30:36, colour = "white", size = 1, alpha = 0.7)+
  facet_grid(ID2~.)+theme_bw()+stellopts+
  scale_fill_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="blue")+
  labs(x = "Distance (km)", y = "Depth (m)", colour = "Salinity", fill = expression(paste('Conc.'~'(ind.'~m^{-3},')')))+
  theme(strip.text.y = element_text(size = 14))+
  geom_ribbon(data = gwcol, aes(x = rrdist2, ymax = rwcol+3, ymin = -40), alpha = 1, fill = 'white')
#ggsave("GonozooidInterpAuto.png", dpi = 300, width = 11, height = 3)

##################remake the manual data with the gonos and phoros separated############
#####Doliolids ECORR nurses vs everyone else#####
setwd("D:/DoliolidsECORR3cats/Nurses")
imgfile <- list.files("D:/DoliolidsECORR3cats/Nurses", pattern=glob2rx("*.tif"))
head(imgfile)

library(stringr)
imgfile <- str_remove(imgfile, "Other_")

#Need to split the string by the underscores- each of these a piece of info
imgf <- unlist(strsplit(imgfile, "[_]"))
imgf <- matrix(imgf, ncol = 8, byrow = T)

head(imgf)
#label the pieces of info - hopefully this is the same for your dataset (it should be)
colnames(imgf) <- c("ID", "Junk", "label", "slice", "xloc", "yloc", "width", "height")
imgf <- as.data.frame(imgf)
head(imgf)
#imgf$newlabel <- paste(imgf$label, imgf$slice, imgf$xloc, imgf$yloc, sep = "_")

#merge new data frame with the environmental data - pcounts = particle data
#create a julian time
label <- as.character(imgf$label)

jul <- substr(label, 9,18)
head(jul)

jul <- as.character(jul)
hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
min <- as.numeric(substr(jul, 3,4))
sec <- as.numeric(substr(jul, 5,6))
sec1000 <- as.numeric(substr(jul, 8,11))

#this is a function that uses the julian time and the slice number within the stack to make a new
#julian time
julianmakerslice <- function(hr, min, sec, sec1000, slice) {
  julian <- (hr/24)+(min/(24*60))+(sec/(24*60*60))+(sec1000/(24*60*60*1000))+(((slice/430)*25.165)/(24*60*60))
  return(julian)
}

julian <- julianmakerslice(hr, min, sec, sec1000, as.numeric(imgf$slice))

a1 <- cbind(julian, imgf)
head(a1)
a1$ID2 <- "Nurse"

setwd("D:/DoliolidsECORR3cats/Nurses-nocode")
imgfile <- list.files("D:/DoliolidsECORR3cats/Nurses-nocode", pattern=glob2rx("*.tif"))
head(imgfile)

library(stringr)
imgfile <- str_remove(imgfile, "Other_")

#Need to split the string by the underscores- each of these a piece of info
imgf <- unlist(strsplit(imgfile, "[_]"))
imgf <- matrix(imgf, ncol = 7, byrow = T)

head(imgf)
dolio <- rep("dolio", times = nrow(imgf))
imgf <- cbind(dolio, imgf)

#label the pieces of info - hopefully this is the same for your dataset (it should be)
colnames(imgf) <- c("ID", "Junk", "label", "slice", "xloc", "yloc", "width", "height")
imgf <- as.data.frame(imgf)
head(imgf)
#imgf$newlabel <- paste(imgf$label, imgf$slice, imgf$xloc, imgf$yloc, sep = "_")

#merge new data frame with the environmental data - pcounts = particle data
#create a julian time
label <- as.character(imgf$label)

jul <- substr(label, 9,18)
head(jul)

jul <- as.character(jul)
hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
min <- as.numeric(substr(jul, 3,4))
sec <- as.numeric(substr(jul, 5,6))
sec1000 <- as.numeric(substr(jul, 8,11))

#this is a function that uses the julian time and the slice number within the stack to make a new
#julian time
julianmakerslice <- function(hr, min, sec, sec1000, slice) {
  julian <- (hr/24)+(min/(24*60))+(sec/(24*60*60))+(sec1000/(24*60*60*1000))+(((slice/430)*25.165)/(24*60*60))
  return(julian)
}

julian <- julianmakerslice(hr, min, sec, sec1000, as.numeric(imgf$slice))

a2 <- cbind(julian, imgf)
head(a2)
a2$ID2 <- "Nurse"

setwd("D:/DoliolidsECORR3cats/Doliolids")
imgfile <- list.files("D:/DoliolidsECORR3cats/Doliolids", pattern=glob2rx("*.tif"))
head(imgfile)

library(stringr)
imgfile <- str_remove(imgfile, "Other_")

#Need to split the string by the underscores- each of these a piece of info
imgf <- unlist(strsplit(imgfile, "[_]"))
imgf <- matrix(imgf, ncol = 8, byrow = T)

head(imgf)
#label the pieces of info - hopefully this is the same for your dataset (it should be)
colnames(imgf) <- c("ID", "Junk", "label", "slice", "xloc", "yloc", "width", "height")
imgf <- as.data.frame(imgf)
head(imgf)
#imgf$newlabel <- paste(imgf$label, imgf$slice, imgf$xloc, imgf$yloc, sep = "_")

#merge new data frame with the environmental data - pcounts = particle data
#create a julian time
label <- as.character(imgf$label)

jul <- substr(label, 9,18)
head(jul)

jul <- as.character(jul)
hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
min <- as.numeric(substr(jul, 3,4))
sec <- as.numeric(substr(jul, 5,6))
sec1000 <- as.numeric(substr(jul, 8,11))

#this is a function that uses the julian time and the slice number within the stack to make a new
#julian time
julianmakerslice <- function(hr, min, sec, sec1000, slice) {
  julian <- (hr/24)+(min/(24*60))+(sec/(24*60*60))+(sec1000/(24*60*60*1000))+(((slice/430)*25.165)/(24*60*60))
  return(julian)
}

julian <- julianmakerslice(hr, min, sec, sec1000, as.numeric(imgf$slice))

a3 <- cbind(julian, imgf)
head(a3)
a3$ID2 <- "Gonozooid"

setwd("D:/DoliolidsECORR3cats/Phoros")
imgfile <- list.files("D:/DoliolidsECORR3cats/Phoros", pattern=glob2rx("*.tif"))
head(imgfile)

library(stringr)
imgfile <- str_remove(imgfile, "Other_")

#Need to split the string by the underscores- each of these a piece of info
imgf <- unlist(strsplit(imgfile, "[_]"))
imgf <- matrix(imgf, ncol = 8, byrow = T)

head(imgf)
#label the pieces of info - hopefully this is the same for your dataset (it should be)
colnames(imgf) <- c("ID", "Junk", "label", "slice", "xloc", "yloc", "width", "height")
imgf <- as.data.frame(imgf)
head(imgf)
#imgf$newlabel <- paste(imgf$label, imgf$slice, imgf$xloc, imgf$yloc, sep = "_")

#merge new data frame with the environmental data - pcounts = particle data
#create a julian time
label <- as.character(imgf$label)

jul <- substr(label, 9,18)
head(jul)

jul <- as.character(jul)
hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
min <- as.numeric(substr(jul, 3,4))
sec <- as.numeric(substr(jul, 5,6))
sec1000 <- as.numeric(substr(jul, 8,11))

#this is a function that uses the julian time and the slice number within the stack to make a new
#julian time
julianmakerslice <- function(hr, min, sec, sec1000, slice) {
  julian <- (hr/24)+(min/(24*60))+(sec/(24*60*60))+(sec1000/(24*60*60*1000))+(((slice/430)*25.165)/(24*60*60))
  return(julian)
}

julian <- julianmakerslice(hr, min, sec, sec1000, as.numeric(imgf$slice))

a4 <- cbind(julian, imgf)
head(a4)
a4$ID2 <- "Phorozooid"

aaa <- rbind(a1, a2, a3, a4) #2 nurse data frames

#read in physical data
setwd("d:/")
phys <- read.csv("20160726physical.csv", header = T, skip = 4)
head(phys)

#change the column names to simple words
colnames(phys) <- c("julian", "utc", "timestamp", "alt", "temp", "depth", "fluor", "fvel", "heading", "o2", "o2volts", 
                    "par", "parvolts", "pitch", "roll", "salinity", "lat", "lon", "vertvel", "altok")

#take physical and create a mean for each rdist
phys$secs <- phys$julian*(24*60*60) 
phys$hdist <- (phys$secs*2.5)-(min(phys$secs*2.5)) 
#phys$rdist <- round_any(phys$hdist, 19.25, ceiling)

bioenv <- nearphys(aaa$julian, phys$julian)

nearjul <- phys[bioenv,1]
aaa <- cbind(nearjul, aaa)
colnames(phys)[1] <- "nearjul"

newfr <- merge(aaa, phys, by = "nearjul", all.x = TRUE)
head(newfr)
tail(newfr)
#write.csv(newfr, file = "726dolenv3cats.csv", row.names = FALSE)

##plot the manual data
dgu <- read.csv("726dolenv3cats.csv", header = TRUE)
#7 seconds per bin
#That is 0.000081 julian time in 7 seconds

dgu$rjul <-round_any(dgu$julian, 0.000081, ceiling)
ddply(dgu, .(ID2), summarise, totnum = length(ID2))

manco <- ddply(dgu, .(rjul, ID2), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat))
head(manco)

ggplot()+geom_tile(data = pp2, aes(dist/1000, -depth, fill = salinity))+
  geom_point(data = manco, aes(mdist/1000, -mdepth, size = pco2), alpha = 0.3)+
  labs(x = "Distance (km)", y = "Depth (m)", size = "Conc.", fill = "Salinity")+
  facet_grid(ID2~.)+
  theme_bw()+lll

#ggsave("ManualDol726.png", dpi = 300)

tmanco <- ddply(dgu, .(rjul), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat))
head(tmanco)

ggplot()+geom_tile(data = pp2, aes(dist/1000, -depth, fill = salinity))+
  geom_point(data = tmanco, aes(mdist/1000, -mdepth, size = pco2), alpha = 0.3)+
  labs(x = "Distance (km)", y = "Depth (m)", size = "Conc.", fill = "Salinity")+
  theme_bw()+lll

tautdol <- ddply(newfr, .(rjul), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat), msal = mean(salinity), sdsal = sd(salinity), vsal = var(salinity), mtemp = mean(temp))
head(tautdol)

ggplot()+geom_tile(data = pp2, aes(dist/1000, -depth, fill = salinity))+
  geom_point(data = tautdol, aes(mdist/1000, -mdepth, size = pco2), alpha = 0.3)+
  labs(x = "Distance (km)", y = "Depth (m)", size = "Conc.", fill = "Salinity")+
  theme_bw()+lll

head(tautdol)
head(tmanco)

manind <- nearphys(tmanco$rjul, tautdol$rjul)
tmanco$autjul <- tautdol[manind, 1]
head(tmanco)
head(tautdol)
colnames(tautdol)[1] <- "autjul"
mana3 <- merge(tmanco, tautdol, by = "autjul", all.y = TRUE)
head(mana3)
mana3[is.na(mana3)] <- 0 

ggplot(mana3, aes(pco2.y, pco2.x))+geom_point()+labs(x = "Automated conc.", y = "Manual conc.")+
  geom_smooth(method = "lm", se = FALSE)+theme_bw()

cor(mana3$pco2.x, mana3$pco2.y, method = "spearman")
head(mana3)

mana3$difco <- mana3$pco2.x-mana3$pco2.y #positive means manual has more, negative means autmoated has more

ggplot(mana3, aes(mdist.y/1000, -mdepth.y, fill = difco))+geom_point(pch = 21, colour = "black", size = 3)+
  labs(x = "Distance (km)", y = "Depth (m)", fill = "Manual-Auto Dols")+
  scale_fill_gradientn(colours = c("blue", "white", "red"), limits = c(-150, 150), na.value = "darkblue")+theme_bw()
#ggsave("TotDolsManAutoSpatial.png", dpi = 300)

ggplot(mana3, aes(mdist.y/1000, -mdepth.y, fill = difco))+geom_point(pch = 21, colour = "black", size = 3)+
  labs(x = "Distance (km)", y = "Depth (m)", fill = "Manual-Auto Dols")+
  scale_fill_gradient2(high = "red", low = "blue", midpoint = 0, limits = c(-180, 130), na.value = "darkblue")+theme_bw()

ggplot()+geom_point(data = mana3, aes(mdist.y/1000, -mdepth.y, fill = difco), pch = 21, colour = "black", size = 3)+
  geom_contour(data = pp2, aes(dist/1000, -depth, z = salinity), colour = "gray20", breaks = 30:36, size = 1.5)+
  labs(x = "Distance (km)", y = "Depth (m)", fill = "Manual-Auto Dols")+
  scale_fill_gradient2(high = "red", low = "blue", midpoint = 0, limits = c(-180, 130), na.value = "darkblue")+theme_bw()
#ggsave("TotDolsManAutoSpatial-contour.png", dpi = 300)

summary(mana3$sdsal)
library(gsw)
mana3$dens <- gsw_sigma0(mana3$msal, mana3$mtemp)
summary(mana3$dens)
mana3$rdens <- round_any(mana3$dens, .4, ceiling) 

difma <- ddply(mana3, .(rdens), summarize, mdif = mean(difco), nsamp = length(rdens), correl = cor(pco2.x, pco2.y, method = "spearman"))
difma

ggplot(difma, aes(rdens, mdif))+geom_path()+geom_point(aes(size = nsamp, colour = correl))+theme_bw()+ylim(-100, 0)+ll+
  labs(x = "Sigma-t", y = "Mean Automated conc. - manual conc.", size = "Number of samples", colour = "Spearman")
#ggsave("AutoManvsSigma-tcorrelsamp.png", dpi = 300)

#max within bin salinity standard deviation
sd1 <- subset(mana3, msal > 30)
sd1 <- subset(mana3, sdsal <.03)
sd1 <- subset(mana3, mdepth.y > 20)
nrow(sd1)
cor(sd1$pco2.x, sd1$pco2.y, method = "spearman")

sd2 <- subset(mana3, mdepth.y >= 8 & mdepth.y <= 10)
nrow(sd2)
cor(sd2$pco2.x, sd2$pco2.y, method = "pearson")
ggplot(sd2, aes(pco2.y, pco2.x))+geom_point()

increm <- seq(0,34,2)
corma <- vector(length = length(increm))
for(i in 1:length(increm)){
  sd2 <- subset(mana3, mdepth.y >= increm[i] & mdepth.y <= increm[i+1])
  corma[i] <- cor(sd2$pco2.x, sd2$pco2.y, method = "spearman")
}

corprof <- data.frame(increm, corma)
colnames(corprof) <- c("depth", "Spearman")

ggplot(corprof, aes(-depth, Spearman))+geom_point()+geom_path()+coord_flip()+theme_bw()+
  labs(x = "Depth (m)")
#ggsave("AutoManCorvDepth.png", dpi = 300)

increm <- seq(22.5,31.5,0.5)
corsa <- vector(length = length(increm))
for(i in 1:length(increm)){
  sd2 <- subset(mana3, mtemp >= increm[i] & mtemp <= increm[i+1])
  corsa[i] <- cor(sd2$pco2.x, sd2$pco2.y, method = "spearman")
}

cortem <- data.frame(increm, corsa)
colnames(cortem) <- c("temp", "Spearman")

ggplot(cortem, aes(temp, Spearman))+geom_point()+geom_path()+theme_bw()
#ggsave("AutoManCorvsTemp.png", dpi = 300)

summary(mana3$sdsal)

increm <- seq(29,36,0.5)
corsa <- vector(length = length(increm))
for(i in 1:length(increm)){
  sd2 <- subset(mana3, msal >= increm[i] & msal <= increm[i+1])
  corsa[i] <- cor(sd2$pco2.x, sd2$pco2.y, method = "spearman")
}

corsal <- data.frame(increm, corsa)
colnames(corsal) <- c("salinity", "Spearman")

ggplot(corsal, aes(salinity, Spearman))+geom_point()+geom_path()+theme_bw()
#ggsave("AutoManCorvSal.png", dpi = 300)

summary(mana3$sdsal)

increm <- seq(0,0.08,0.00001)
corsad <- vector(length = length(increm))
for(i in 1:max(increm)){
  sd2 <- subset(mana3, sdsal >= increm[i] & sdsal <= increm[i+1])
  corsad[i] <- cor(sd2$pco2.x, sd2$pco2.y, method = "spearman")
}

corsald <- data.frame(seq(0,.08,0.00001), corsad)
colnames(corsald) <- c("SD.salinity", "Spearman")

ggplot(corsald, aes(SD.salinity, Spearman))+geom_point()+geom_path()+theme_bw()

nrow(subset(mana3, sdsal >= 0.001 & sdsal <= 0.002))

mana3$dens <- gsw_sigma0(mana3$msal, mana3$mtemp)
summary(mana3$dens)

increm <- seq(17,24.8,0.4)
corma <- vector(length = length(increm))
for(i in 1:length(increm)){
  sd2 <- subset(mana3, mdepth.y >= increm[i] & mdepth.y <= increm[i+1])
  corma[i] <- cor(sd2$pco2.x, sd2$pco2.y, method = "spearman")
}

corde <- data.frame(increm, corma)
colnames(corde) <- c("sigmat", "Spearman")

ggplot(corde, aes(sigmat, Spearman))+geom_point()+geom_path()+theme_bw()+
  labs(x = "Sigma-t")
#ggsave("AutoManCorvSigma.png", dpi = 300)

summary(mana3$vsal)
increm <- seq(0,.00469,.0001)
corsad <- vector(length = length(increm))
for(i in 1:max(increm)){
  sd2 <- subset(mana3, vsal >= increm[i] & vsal <= increm[i+1])
  corsad[i] <- cor(sd2$pco2.x, sd2$pco2.y, method = "spearman")
}

corsald <- data.frame(increm, corsad)
colnames(corsald) <- c("var.salinity", "Spearman")

ggplot(corsald, aes(var.salinity, Spearman))+geom_point()+geom_path()+theme_bw()

############try manual/auto correlation with zeros added from physical data
###and with counts for each of the 3 categories
nnf <- read.csv("newphysautodolmerged.csv", header = TRUE)
nrow(nnf) #already has an rjul column

dgu <- read.csv("726dolenv3cats.csv", header = TRUE)
#7 seconds per bin
#That is 0.000081 julian time in 7 seconds

dgu$rjul <-round_any(dgu$julian, 0.000081, ceiling)
tmanco <- ddply(dgu, .(rjul, ID2), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat))
head(tmanco)
manc <- dcast(tmanco, rjul~ID2, value.var = "pco2")
manc$rjul <- round(manc$rjul, digits = 7)

tautdol <- ddply(nnf, .(rjul, PREDICTED_GROUP), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat), msal = mean(salinity), sdsal = sd(salinity), vsal = var(salinity), mtemp = mean(temp))
head(tautdol)
autc <- dcast(tautdol, rjul~PREDICTED_GROUP, value.var = "pco2")
autc$rjul <- round(autc$rjul, digits = 7)


tcon <- merge(manc, autc, by = "rjul", all = TRUE)
tcon[is.na(tcon)] <- 0 
#stcon <- ddply(tcon, .(rjul), summarise, manGon = sum(Gonozooid), manNurse = sum(Nurse), manPhor = sum(Phorozooid), aGon = sum(tunicate_doliolid), aPhor = sum(tunicate_doliolid_juvenile_buds), aNurse = sum(tunicate_doliolid_nurse))
#duplicated(round(stcon$rjul, digits = 7)
colnames(tcon) <- c("rjul", "mGon", "mNurse", "mPhor", "aGon", "aPhor", "aNurse")
cor(tcon$mGon, tcon$aGon, method = "spearman")
cor(tcon$mPhor, tcon$aPhor, method = "spearman")
cor(tcon$mNurse, tcon$aNurse, method = "spearman") #nurses have best correlation, gonos worst

#read in the physical data and average to .000081 then merge with the counts from auto and manual
#keep all phys data and turn NAs to zeros
phys <- read.csv("20160726physical.csv", header = T, skip = 4)
head(phys)

#change the column names to simple words
colnames(phys) <- c("julian", "utc", "timestamp", "alt", "temp", "depth", "fluor", "fvel", "heading", "o2", "o2volts", 
                    "par", "parvolts", "pitch", "roll", "salinity", "lat", "lon", "vertvel", "altok")

#take physical and create a mean for each rdist
phys$secs <- phys$julian*(24*60*60) 
phys$hdist <- (phys$secs*2.5)-(min(phys$secs*2.5)) 
phys$rjul <-round_any(phys$julian, 0.000081, ceiling)

#need to declare the variables before the formulae within
oxygenc <- function(temp, pressure, salinity, o2volts) {
  soc <- 0.4980
  voffset <- -0.5111
  tau20 <- 1.94
  D1 <- 1.92634e-4
  D2 <- -4.64803e-2
  tauTP <- tau20*exp(D1*pressure+D2*(temp-20))
  A <- -4.1500e-3
  B <- 2.1162e-4
  C <- -3.2483e-6
  E <- 0.036
  H1 <- -3.3e-2
  H2 <- 5e3
  H3 <- 1.45e3
  A0 <- 2.00907
  A1 <- 3.22014
  A2 <- 4.0501
  A3 <- 4.94457
  A4 <- -0.256847
  A5 <- 3.88767
  B0 <- -0.00624523
  B1 <- -0.00737614
  B2 <- -0.010341
  B3 <- -0.00817083
  C0 <- -4.88682e-7
  Kelvin <- temp+273.15
  Ts <- log((298.15-temp)/(273.15+temp))
  Oxsol <- exp(A0+(A1*Ts)+(A2*(Ts^2))+(A3*(Ts^3))+(A4*(Ts^4))+(A5*(Ts^5))+salinity*((B0+(B1*Ts))+(B2*(Ts^2))+(B3*(Ts^3)))+(C0*(salinity^2)))
  
  o2conc <- soc*(o2volts+voffset)*Oxsol*(1+(A*temp)+(B*temp^2)+(C*temp^3))*exp(E*pressure/Kelvin)
  return(o2conc)
  
}
oxygenc(20, 0, 0, 2.739) #should read 6.89
#this produces mL/L of O2- if you want mg/L, then divide the result by 0.75189 (see ICES unit conversion)

phys$o2 <- oxygenc(phys$temp, phys$depth, phys$salinity, phys$o2volts)/0.75189 #convert to mg/L
delen <- 21 #delay by 21 for the o2 pump
phys$o2delay <- c(phys$o2[(delen+1):nrow(phys)], rep(phys$o2[nrow(phys)], delen))


psum <- ddply(phys, .(rjul), summarise, mdep = mean(depth), mlat = mean(lat), msal = mean(salinity), mtemp = mean(temp), mo2 = mean(o2delay), mfluor = mean(fluor), mdist = mean(hdist))

pdol <- merge(psum, tcon, by = "rjul")
#a few rjuls are being missed - pdol should be larger than tcon but it is not

manind <- nearphys(tcon$rjul, psum$rjul)
tcon$rjul2 <- psum[manind, 1]
colnames(psum)[1] <- "rjul2"
pdol <- merge(psum, tcon, by = "rjul2", all.x = TRUE)

head(pdol)
pdol[is.na(pdol)] <- 0
cor(pdol$mGon, pdol$aGon, method = "spearman")
cor(pdol$mPhor, pdol$aPhor, method = "spearman")
cor(pdol$mNurse, pdol$aNurse, method = "spearman") #nurses have best correlation, gonos worst - better if you add zeros

pdol$gondif <- pdol$mGon - pdol$aGon
pdol$phdif <- pdol$mPhor - pdol$aPhor
pdol$nurdif <- pdol$mNurse - pdol$aNurse
pdol$totadol <- pdol$aPhor + pdol$aGon + pdol$aNurse

ggplot(pdol, aes(totadol, aGon, colour = gondif))+geom_point()+ll

#plot the discrepencies for each 
head(pdol)
ddif <- pdol[,c(2, 8, 16:18)]
head(ddif)
colnames(ddif)[3:5] <- c("Gonozooid", "Phorozooid", "Nurse")

mdd <- melt(ddif, id.vars = c("mdep", "mdist"))

pp2 <- read.csv("726salinityinterp.csv", header = TRUE)

ggplot()+geom_tile(data = pp2, aes(dist/1000, -depth, fill = salinity))+
  geom_point(data = mdd, aes(mdist/1000, -mdep, colour = value), alpha = 0.7)+
  labs(x = "Distance (km)", y = "Depth (m)", colour = "Manual-Auto")+
  scale_colour_gradientn(colours = c("blue", "white", "red"), limits = c(-200, 200))+
  facet_grid(variable~.)+
  theme_bw()+lll

ggplot()+
  geom_point(data = mdd, aes(mdist/1000, -mdep, colour = value), alpha = 0.7)+
  geom_contour(data = pp2, aes(dist/1000, -depth, z = salinity), breaks = 30:36, colour = "grey70", size = 1)+
  labs(x = "Distance (km)", y = "Depth (m)", colour = "Manual-Auto")+
  scale_colour_gradientn(colours = c("blue", "black", "red"), limits = c(-200, 200))+
  facet_grid(variable~.)+theme_bw()

mdd$variable <- factor(mdd$variable, levels=c("Gonozooid", "Nurse", "Phorozooid"))
ggplot(mdd, aes(value))+geom_histogram(binwidth = 1)+facet_grid(variable~., scales = "free_y")+xlim(-40,40)+theme_bw()+
  labs(x = "Manual - Automated Abundance", y = "Frequency (n = 2913)")+stellopts+
  theme(strip.text.y = element_text(size = 14))
#ggsave("ManAutoHist-final.png", dpi = 300)

#profile of the correlation coefficient with depth for the 3 life stages
head(pdol)
increm <- seq(0,34,2)
corma <- vector(length = length(increm))
abun <- vector(length = length(increm))
for(i in 1:length(increm)){
  sd2 <- subset(pdol, mdep >= increm[i] & mdep <= increm[i+1])
  corma[i] <- cor(sd2$mGon, sd2$aGon, method = "spearman")
  abun[i] <- sum(sd2$aGon)/nrow(sd2)
}

corprof1 <- data.frame(increm, corma, abun)
colnames(corprof1) <- c("depth", "Spearman", "Abundance")
corprof1$lstage <- "Gonozooid"

corma <- vector(length = length(increm))
abun <- vector(length = length(increm))
for(i in 1:length(increm)){
  sd2 <- subset(pdol, mdep >= increm[i] & mdep <= increm[i+1])
  corma[i] <- cor(sd2$mNurse, sd2$aNurse, method = "spearman")
  abun[i] <- sum(sd2$aNurse)/nrow(sd2)
}

corprof2 <- data.frame(increm, corma, abun)
colnames(corprof2) <- c("depth", "Spearman", "Abundance")
corprof2$lstage <- "Nurse"

corma <- vector(length = length(increm))
abun <- vector(length = length(increm))
for(i in 1:length(increm)){
  sd2 <- subset(pdol, mdep >= increm[i] & mdep <= increm[i+1])
  corma[i] <- cor(sd2$mPhor, sd2$aPhor, method = "spearman")
  abun[i] <- sum(sd2$aPhor)/nrow(sd2)
}

corprof3 <- data.frame(increm, corma, abun)
colnames(corprof3) <- c("depth", "Spearman", "Abundance")
corprof3$lstage <- "Phorozooid"

cordep <- rbind(corprof1, corprof2, corprof3)

ggplot()+geom_point(data = cordep, aes(-depth, Spearman, colour = lstage, size = Abundance))+
  geom_path(data = cordep, aes(-depth, Spearman, colour = lstage), size = 0.5)+coord_flip()+theme_bw()+
  geom_vline(xintercept = -8, linetype = 2)+
  geom_vline(xintercept = -14, linetype = 2)+scale_colour_brewer(palette = "Set1")+
  scale_size_continuous(range = c(1.5, 8), limits = c(0.01, 80))+
  labs(x = "Depth (m)", y = "Manual v. Auto Spearman's correlation", size = expression(paste('Mean Abundance'~'(ind.'~m^{-3},')')), colour = "Life Stage")
ggsave("ManAutoCorrel-depth.png", dpi = 300)

tmanco$autjul <- tautdol[manind, 1]
head(tmanco)
head(tautdol)
colnames(tautdol)[1] <- "autjul"
mana3 <- merge(tmanco, tautdol, by = "autjul", all.y = TRUE)
head(mana3)
mana3[is.na(mana3)] <- 0 

ggplot(mana3, aes(pco2.y, pco2.x))+geom_point()+labs(x = "Automated conc.", y = "Manual conc.")+
  geom_smooth(method = "lm", se = FALSE)+theme_bw()

cor(mana3$pco2.x, mana3$pco2.y, method = "spearman")
head(mana3)

mana3$difco <- mana3$pco2.x-mana3$pco2.y 

#find max and min lat/lon in medit
setwd("d:/")
vfs <- read.csv("env_visufront_cc.csv", header = TRUE)
ddply(vfs, .(transect), summarise, slon = min(lon), elong = max(lon), slat = min(lat), elat = max(lat))
head(vfs)
