#Read in the doliolid data from different systems and bin to a certain julian time window
#packages and other stuff
library(ggplot2)
library(reshape2)
library(plyr)
library(akima)

ll <- scale_colour_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white")
lll <- scale_fill_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white")

stellopts <- theme(legend.text= element_text(size = 14),legend.title = element_text(size = 14, face = 'bold'),axis.title.x = element_text(size = 14), axis.title.y = element_text(size = 14, angle =90),axis.text.x = element_text(size =14), axis.text.y = element_text(size = 14), panel.grid.minor = element_blank(), panel.grid.major = element_blank())

julianmaker2 <- function(hr, minu, sec) {
  julian <- (hr/24)+(minu/(24*60))+(sec/(24*60*60))
  return(julian)
}

#use to make julian time if the image is a "slice" within a stack of tiff images - timestamp is the name of the file and the first image
julianmakerslice <- function(hr, minu, sec, slice) {
  julian <- (hr/24)+(minu/(24*60))+(sec/(24*60*60))+(((slice/430)*25.165)/(24*60*60))
  return(julian)
}

#need to declare the variables before the formulae within
oxygenc <- function(temp, pressure, salinity, o2volts) {
  soc <- 0.4980
  voffset <- -0.5111
  tau20 <- 1.94
  D1 <- 1.92634e-4
  D2 <- -4.64803e-2
  tauTP <- tau20*exp(D1*pressure+D2*(temp-20))
  A <- -4.1500e-3
  B <- 2.1162e-4
  C <- -3.2483e-6
  E <- 0.036
  H1 <- -3.3e-2
  H2 <- 5e3
  H3 <- 1.45e3
  A0 <- 2.00907
  A1 <- 3.22014
  A2 <- 4.0501
  A3 <- 4.94457
  A4 <- -0.256847
  A5 <- 3.88767
  B0 <- -0.00624523
  B1 <- -0.00737614
  B2 <- -0.010341
  B3 <- -0.00817083
  C0 <- -4.88682e-7
  Kelvin <- temp+273.15
  Ts <- log((298.15-temp)/(273.15+temp))
  Oxsol <- exp(A0+(A1*Ts)+(A2*(Ts^2))+(A3*(Ts^3))+(A4*(Ts^4))+(A5*(Ts^5))+salinity*((B0+(B1*Ts))+(B2*(Ts^2))+(B3*(Ts^3)))+(C0*(salinity^2)))
  
  o2conc <- soc*(o2volts+voffset)*Oxsol*(1+(A*temp)+(B*temp^2)+(C*temp^3))*exp(E*pressure/Kelvin)
  return(o2conc)
  
}
oxygenc(20, 0, 0, 2.739) #should read 6.89
#this produces mL/L of O2- if you want mg/L, then divide the result by 0.75189 (see ICES unit conversion)

#function to merge physical and image times (julian)
nearphys <- function(x,y) {
  n <- length(x) #x will be the biological data
  phystime <- vector(length = n)
  for(i in 1:n) {
    phystime[i] <- which.min(abs(x[i]-y))
  }
  return(phystime)
}

#function to calculate Lloyd's patchiness index
lloyds <- function(x) {patchiness = 1+((var(x)-mean(x))/(mean(x))^2)
return(patchiness)}

#Oregon 2018
setwd("d:/")
load("205_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dor1 <- subset(dor, totdol > 0)

label <- as.character(dor1$time_Pacific)

jul <- substr(label, 12,19)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 4,5))
sec <- as.numeric(substr(jul, 7,8))

dor1$njul <- julianmaker2(hr, minu, sec)

#7 seconds per bin
#That is 0.000081 julian time in 7 seconds
dor1$rjul <- round_any(dor1$njul, .000081, ceiling)

orc2018 <- ddply(dor1, .(rjul), summarise, sdol = sum(tunicate_doliolid), buds = sum(tunicate_doliolid_budding), nurse = sum(tunicate_doliolid_with_nurse), 
                 dolconc = sum(totdol), mdepth = mean(as.numeric(Depth)), msal = mean(as.numeric(Salinity)), mtemp = mean(as.numeric(Temp)), mfluor = mean(Fluoro), moxy = mean(Oxygen), mirr = mean(irradiance), mlat = mean(Lat), mlon = mean(Long))

ggplot(orc2018, aes(mlon, -mdepth, size = dolconc))+geom_point()
#write.csv(orc2018, "OR2018-dolconc.csv", row.names = FALSE)

#CA 2018
load("213_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dca1 <- subset(dor, totdol > 0)

label <- as.character(dca1$time_Pacific)

jul <- substr(label, 12,19)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 4,5))
sec <- as.numeric(substr(jul, 7,8))

dca1$njul <- julianmaker2(hr, minu, sec)

#7 seconds per bin
#That is 0.000081 julian time in 7 seconds
dca1$rjul <- round_any(dca1$njul, .000081, ceiling)

cac2018 <- ddply(dca1, .(rjul), summarise, sdol = sum(tunicate_doliolid), buds = sum(tunicate_doliolid_budding), nurse = sum(tunicate_doliolid_with_nurse), 
                 dolconc = sum(totdol), mdepth = mean(as.numeric(Depth)), msal = mean(as.numeric(Salinity)), mtemp = mean(as.numeric(Temp)), mfluor = mean(Fluoro), moxy = mean(Oxygen), mirr = mean(irradiance), mlat = mean(Lat), mlon = mean(Long))

ggplot(cac2018, aes(mlon, -mdepth, size = dolconc))+geom_point()
#write.csv(cac2018, "CA2018-dolconc.csv", row.names = FALSE)

#Oregon 2019
load("425_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dor2 <- subset(dor, totdol > 0)

label <- as.character(dor2$time_Pacific)

jul <- substr(label, 12,19)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 4,5))
sec <- as.numeric(substr(jul, 7,8))

dor2$njul <- julianmaker2(hr, minu, sec)

#7 seconds per bin
#That is 0.000081 julian time in 7 seconds
dor2$rjul <- round_any(dor2$njul, .000081, ceiling)

orc2019 <- ddply(dor2, .(rjul), summarise, sdol = sum(tunicate_doliolid), buds = sum(tunicate_doliolid_budding), nurse = sum(tunicate_doliolid_with_nurse), 
                 dolconc = sum(totdol), mdepth = mean(Depth), msal = mean(Salinity), mtemp = mean(Temp), mfluor = mean(Fluoro), moxy = mean(Oxygen), mirr = mean(irradiance), mlat = mean(Lat), mlon = mean(Long))

ggplot(orc2019, aes(mlon, -mdepth, size = dolconc))+geom_point()
#write.csv(orc2019, "OR2019-dolconc.csv", row.names = FALSE)

#CA 2019
load("401_doliolids_reduced.RData")
dor <- select_doliol
dor$totdol <- dor$tunicate_doliolid+dor$tunicate_doliolid_budding+dor$tunicate_doliolid_with_nurse
dca2 <- subset(dor, totdol > 0)

#make a julian time for CA 2019
label <- as.character(dca2$time_Pacific)

jul <- substr(label, 12,19)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 4,5))
sec <- as.numeric(substr(jul, 7,8))

dca2$njul <- julianmaker2(hr, minu, sec)

#7 seconds per bin
#That is 0.000081 julian time in 7 seconds
dca2$rjul <- round_any(dca2$njul, .000081, ceiling)

cac2019 <- ddply(dca2, .(rjul), summarise, sdol = sum(tunicate_doliolid), buds = sum(tunicate_doliolid_budding), nurse = sum(tunicate_doliolid_with_nurse), 
      dolconc = sum(totdol), mdepth = mean(Depth), msal = mean(Salinity), mtemp = mean(Temp), mfluor = mean(Fluoro), moxy = mean(Oxygen), mirr = mean(irradiance), mlat = mean(Lat), mlon = mean(Long))

ggplot(cac2019, aes(mlon, -mdepth, size = dolconc))+geom_point()
#write.csv(cac2019, "CA2019-dolconc.csv", row.names = FALSE)

#manual data counts
setwd("d:/")
dgu <- read.csv("726dolenv3cats.csv", header = TRUE)
dgu$rjul <-round_any(dgu$julian, 0.000081, ceiling)

dgu$oxy2 <- oxygenc(dgu$temp, dgu$depth, dgu$salinity, dgu$o2volts)/0.75189

manco <- ddply(dgu, .(rjul, ID2), summarise, pco2 = length(ID2), mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), 
               mfluor = mean(fluor), moxy = mean(oxy2), mpar = mean(par), mlat = mean(lat), mlon = mean(lon))
head(manco)
summary(manco$moxy)
sco <- dcast(manco, rjul ~ ID2, value.var = "pco2")
sco[is.na(sco)] <- 0
head(sco)
comme <- merge(sco, manco, by = "rjul", all = TRUE)

#remove the duplicated rows - all physical values are pretty close, so it doesn't really matter
com2 <- comme[!duplicated(comme$rjul),]
#get rid of the 2 columns from the manco dataframe that are now meaningless 
com2 <- com2[,c(-5,-6)]
head(com2)
com2$totdol <- com2[,2] + com2[,3] + com2[,4]


ggplot(com2, aes(mlat, -mdepth, size = totdol))+geom_point()
#write.csv(com2, file = "ManualDolEnv.csv", row.names = FALSE)
com2 <- read.csv("ManualDolEnv.csv", header = TRUE)
head(com2)

#Automated doliolids for ECORR and MCORR - need to merge with physical data first then bin by .000081 julian time
#ECORR merged with physical
newfr <- read.csv("newphysautodolmerged.csv", header = TRUE) #ECORR 

setwd("d:/PTS03_085_MCORR")
dols <- read.csv("PTS03_085_T029_MCORR_ft_ess_tunicate_doliolid.csv", header = TRUE)
nur <- read.csv("PTS03_085_T029_MCORR_ft_ess_tunicate_doliolid_nurse.csv", header = TRUE)
bud <- read.csv("PTS03_085_T029_MCORR_ft_ess_tunicate_doliolid_juvenile_buds.csv", header = TRUE)
head(nur)

ggplot(nur, aes(LATITUDE_DEG, -DEPTH_M))+geom_point()

tdol <- rbind(dols, nur, bud)

label <- as.character(tdol$SEGMENT_FILENAME)

jul <- substr(label, 5,23)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 5,6)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 7,8))
sec <- as.numeric(substr(jul, 9,14))
slice <- as.numeric(substr(jul, 17,19))

tdol$njul <- julianmakerslice(hr, minu, sec, slice)

#merge the abundances of total doliolids to physical data using the same method as dolenv
setwd("d:/")
phys <- read.csv("072516physical.csv", header = T, skip = 4)
head(phys)

#change the column names to simple words
colnames(phys) <- c("julian", "utc", "timestamp", "alt", "temp", "depth", "fluor", "fvel", "heading", "o2", "o2volts", 
                    "par", "parvolts", "pitch", "roll", "salinity", "lat", "lon", "vertvel", "altok")

#take physical and create a mean for each rdist
phys$secs <- phys$julian*(24*60*60) 
phys$hdist <- (phys$secs*2.5)-(min(phys$secs*2.5)) 
phys$rdist <- round_any(phys$hdist, 17, ceiling)

phys$oxy2 <- oxygenc(phys$temp, phys$depth, phys$salinity, phys$o2volts)/0.75189

bioenv <- nearphys(tdol$njul, phys$julian)

nearjul <- phys[bioenv,1]
tdol <- cbind(nearjul, tdol)
colnames(phys)[1] <- "nearjul"

newfr2 <- merge(tdol, phys, by = "nearjul", all.x = TRUE)
head(newfr2)
tail(newfr2)
#write.csv(newfr2, "MCORRautodolmerged.csv", row.names = FALSE)
newfr2$rjul <-round_any(newfr2$njul, 0.000081, ceiling)

pp2 <- read.csv("725salinityinterp.csv", header = TRUE)

autdol <- ddply(newfr2, .(rjul, PREDICTED_GROUP), summarize, mdepth = mean(depth), pco2 = length(rjul), mdist = mean(hdist), mlat = mean(lat))
head(autdol)

ggplot()+geom_tile(data = pp2, aes(dist/1000, -depth, fill = salinity))+
  geom_point(data = autdol, aes(mdist/1000, -mdepth, size = pco2), alpha = 0.3)+
  labs(x = "Distance (km)", y = "Depth (m)", size = "Conc.", fill = "Salinity")+
  facet_grid(PREDICTED_GROUP~.)+
  theme_bw()+lll
#ggsave("AutoDol725.png", dpi = 300)

MCORR <- ddply(newfr2, .(rjul, PREDICTED_GROUP), summarise, dolconc = length(PREDICTED_GROUP), 
                 mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), mfluor = mean(fluor), moxy = mean(oxy2), mirr = mean(par), mlat = mean(lat), mlon = mean(lon))
head(MCORR)
ggplot(MCORR, aes(mlat, -mdepth, colour = moxy))+geom_point()+ll

dcou <- MCORR[,1:3]
head(dcou)
rdc <- dcast(dcou, rjul~PREDICTED_GROUP, value.var = "dolconc")
#change NA to zero
rdc[is.na(rdc)] <- 0
colnames(rdc) <- c("rjul", "sdol", "nurse", "buds")
rdc$dolconc <- rdc$sdol + rdc$nurse + rdc$buds

phr <- ddply(newfr2, .(rjul), summarise, 
      mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), mfluor = mean(fluor), moxy = mean(oxy2), mirr = mean(par), mlat = mean(lat), mlon = mean(lon))
mcc <- cbind(rdc, phr)
head(mcc)
#write.csv(mcc, file = "GOM-MCORR2016-dolconc.csv", row.names = FALSE)

#automated gulf of mexico data - ECORR and MCORR
newfr <- read.csv("newphysautodolmerged.csv", header = TRUE) #ECORR 
newfr$oxy2 <- oxygenc(newfr$temp, newfr$depth, newfr$salinity, newfr$o2volts)/0.75189
#newfr$rjul <-round_any(newfr$njul, 0.000081, ceiling)

pp2 <- read.csv("726salinityinterp.csv", header = TRUE)

ECORR <- ddply(newfr, .(rjul, PREDICTED_GROUP), summarise, dolconc = length(PREDICTED_GROUP), 
               mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), mfluor = mean(fluor), moxy = mean(oxy2), mirr = mean(par), mlat = mean(lat), mlon = mean(lon))
head(ECORR)

dcou <- ECORR[,1:3]
head(dcou)
rdc <- dcast(dcou, rjul~PREDICTED_GROUP, value.var = "dolconc")
#change NA to zero
rdc[is.na(rdc)] <- 0
colnames(rdc) <- c("rjul", "sdol", "nurse", "buds")
rdc$dolconc <- rdc$sdol + rdc$nurse + rdc$buds

phr <- ddply(newfr, .(rjul), summarise, 
             mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), mfluor = mean(fluor), moxy = mean(oxy2), mirr = mean(par), mlat = mean(lat), mlon = mean(lon))
mcc <- cbind(rdc, phr)
head(mcc)
#write.csv(mcc, file = "GOM-ECORR2016-dolconc.csv", row.names = FALSE)




#San Diego data - only total doliolids
sddo <- read.csv("doliolids_transects2_3_presence_only.csv", header = TRUE)

label <- as.character(sddo$dateTime)

jul <- substr(label, 12,23)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 4,5))
sec <- as.numeric(substr(jul, 7,12))

sddo$njul <- julianmaker2(hr, minu, sec)

#7 seconds per bin
#That is 0.000081 julian time in 7 seconds
sddo$rjul <- round_any(sddo$njul, .000081, ceiling)
colnames(sddo)[6] <- "pco" #change the column name because "count" is a function

sd2010 <- ddply(sddo, .(rjul, transect), summarise,
                 dolconc = sum(pco), mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), mfluor = mean(fluoro), moxy = mean(oxygen), mlat = mean(lat), mlon = mean(long))

ggplot(sd2010, aes(mlon, -mdepth, size = dolconc))+geom_point()+facet_wrap(~transect)
#write.csv(sd2010, file = "SD2010-dolconc.csv", row.names = FALSE)





#Staits of Florida data
#untar("doliolid_data.tar.gz",list=TRUE)  ## check contents
#untar("tmp.tar.gz")
## or, if you just want to extract the target file:
#untar("doliolid_data.tar.gz")
#3W is from 2014. 7W is from 2015

load("all_joined_3W_doliolid_unbinned_90FTclass.Rdata")
fl3w <- d
head(fl3w)
tail(fl3w)

unique(fl3w$group)
levels(fl3w$group)

#make a julian time for FL 2014
label <- as.character(fl3w$dateTime)

jul <- substr(label, 12,19)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 4,5))
sec <- as.numeric(substr(jul, 7,8))

fl3w$njul <- julianmaker2(hr, minu, sec)

#7 seconds per bin
#That is 0.000081 julian time in 7 seconds
fl3w$rjul <- round_any(fl3w$njul, .000081, ceiling)
colnames(fl3w)[3] <- "dolc"

fl2014 <- ddply(fl3w, .(rjul), summarise,
                dolconc = sum(dolc), mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), mfluor = mean(fluoro), mirr = mean(irradiance), mlat = mean(lat), mlon = mean(lon))

ggplot(fl2014, aes(mlon, -mdepth, size = dolconc))+geom_point()
#write.csv(fl2014, file = "Fl2014-dolcon.csv", row.names = FALSE)

load("all_joined_10W-7W_doliolid_unbinned_90FTclass.Rdata")
fl7w <- d


tail(fl7w)
fl7 <- subset(fl7w, transect.id == "OST15-Spatial-7W-Und")
head(fl7)
tail(fl7)

#make a julian time for FL 2015
label <- as.character(fl7$dateTime)

jul <- substr(label, 12,19)
head(jul)

jul <- as.character(jul)

hr <- substr(jul, 1,2)
hr <- as.numeric(hr)
minu <- as.numeric(substr(jul, 4,5))
sec <- as.numeric(substr(jul, 7,8))

fl7$njul <- julianmaker2(hr, minu, sec)

#7 seconds per bin
#That is 0.000081 julian time in 7 seconds
fl7$rjul <- round_any(fl7$njul, .000081, ceiling)
colnames(fl7)[3] <- "dolc"

fl2015 <- ddply(fl7, .(rjul), summarise,
                 dolconc = sum(dolc), mdepth = mean(depth), msal = mean(salinity), mtemp = mean(temp), mfluor = mean(fluoro), mirr = mean(irradiance), mlat = mean(lat), mlon = mean(lon))

ggplot(fl2015, aes(mlon, -mdepth, size = dolconc))+geom_point()
ggplot(subset(fl2015, dolconc > 0), aes(rjul, -mdepth, size = dolconc))+geom_point()
#ggsave("FL2015-rawconc.png", dpi = 300)
#write.csv(fl2015, file = "Fl2015-dolcon.csv", row.names = FALSE)



#all the transects com2 (manual), fl2014, fl2015, cac2019, orc2019, orc2018, cac2018, sd2010
#read in the data first
setwd("d:/")
fl2014 <- read.csv("Fl2014-dolcon.csv", header = TRUE)
fl2015 <- read.csv("Fl2015-dolcon.csv", header = TRUE)
cac2019 <- read.csv("CA2019-dolconc.csv", header = TRUE)
orc2019 <- read.csv("OR2019-dolconc.csv", header = TRUE)
orc2018 <- read.csv("OR2018-dolconc.csv", header = TRUE)
cac2018 <- read.csv("CA2018-dolconc.csv", header = TRUE)
sd2010 <- read.csv("SD2010-dolconc.csv", header = TRUE)
newfr <- read.csv("GOM-ECORR2016-dolconc.csv", header = TRUE)
newfr2 <- read.csv("GOM-MCORR2016-dolconc.csv", header = TRUE)

med1 <- read.csv("med_dols_summary_1mbin.csv", header = TRUE)
med1 <- subset(med1, rjul != "NaN")
head(med1)
tail(med1)

mdt <- med1[,c(5:9)]
mdt$Location <- "Mediterranean"

head(fl2014)
flt <- rbind(fl2014[,2:6], fl2015[,2:6])
flt$Location <- "Florida"

head(cac2018)
cat1 <- rbind(cac2018[,5:9], cac2019[,5:9])
cat1$Location <- "N. California"

head(orc2018)
ort <- rbind(orc2018[,5:9], orc2019[,5:9])
ort$Location <- "Oregon"

#just use the automated data for nGOM
#head(com2)
#gomt <- com2[,c(12, 4:7)]
#gomt$Location <- "Gulf of Mexico"
#colnames(gomt)[1] <- "dolconc"

head(newfr)
gomt <- newfr[,c(5, 7:10)]
gomt$Location <- "Gulf of Mexico"

head(newfr2)
gomt2 <- newfr2[,c(5, 7:10)]
gomt2$Location <- "Gulf of Mexico"

head(sd2010)
sdt <- sd2010[,3:7]
sdt$Location <- "S. California"

dolto <- rbind(flt, cat1, ort, gomt, sdt, gomt, gomt2, mdt)

ggplot(subset(dolto, dolconc < 400), aes(mtemp, msal, colour = dolconc, shape = Location))+geom_point()+ll

ggplot(subset(dolto, dolconc < 700), aes(mtemp, msal, colour = Location, size = dolconc))+geom_point()


#x = salinity values, y = temp values
library(gsw)
gsw_sigma0(35,20)

sigdat <- transform(expand.grid(x=seq(7,33,by = 0.2),
                                y=seq(26,39,by = 0.2)),z=gsw_sigma0(y, x))


#remake the plot with the density contours and looking nicer
stellopts <- theme(legend.text= element_text(size = 14),legend.title = element_text(size = 14, face = 'bold'),axis.title.x = element_text(size = 14), axis.title.y = element_text(size = 14, angle =90),axis.text.x = element_text(size =14), axis.text.y = element_text(size = 14), panel.grid.minor = element_blank(), panel.grid.major = element_blank())

nrow(subset(dolto, dolconc == 0))
subset(dolto, dolconc == 0) #some zero counts in Florida data
#get rid of some of the really high values
dolto2 <- subset(dolto, dolconc < 2000 & dolconc > 0)

tsdol <- ggplot(dolto2, aes(mtemp, msal, colour = Location, size = dolconc))+
  geom_contour(data = sigdat, aes(x, y, z=z), breaks = seq(12,30,1), size = 0.8, colour = "black")+
  geom_point(alpha = 0.3)+scale_colour_brewer(palette = "Set1")+theme_bw()+stellopts+
  scale_y_continuous(breaks = seq(26,38,2))+
  labs(x = expression(paste("Temp. (", degree~C,")")), y = "Salinity", colour = "", size = expression(paste('Conc.'~'(ind.'~m^{-3},')')))
  
  
  tsdol + guides(color = guide_legend(override.aes = list(size = 4))) #make the symbols bigger in the legend
  


library(RColorBrewer)
brewer.pal(n = 8, name = "Set1")
tsdol <- ggplot(dolto2, aes(mtemp, msal, colour = Location, size = dolconc))+
  geom_contour(data = sigdat, aes(x, y, z=z), breaks = seq(12,30,1), size = 0.8, colour = "black")+
  geom_point(alpha = 0.3)+scale_colour_manual(values = c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3", "#FF7F00", "grey50"))+theme_bw()+stellopts+
  scale_y_continuous(breaks = seq(26,38,2))+
  labs(x = expression(paste("Temp. (", degree~C,")")), y = "Salinity", colour = "", size = expression(paste('Conc.'~'(ind.'~m^{-3},')')))
tsdol + guides(color = guide_legend(override.aes = list(size = 4))) #make the symbols bigger in the legend
#ggsave("DolTS-6systems-nGOMauto.png", dpi = 300)

#############round the temp and salinity then plot with the ecosystem as a shape
head(dolto)
dolto$rsal <- round_any(dolto$msal, 0.25, ceiling)
dolto$rtemp <- round_any(dolto$mtemp, 0.25, ceiling)
mdol <- ddply(dolto, .(Location, rsal, rtemp), summarize, mdolc = mean(dolconc), nmeas = length(dolconc))
head(mdol)
#colnames(mdol) <- c("location", "rsal", "rtemp", "mdolc", "nmeas")

ggplot()+
  geom_contour(data = sigdat, aes(x, y, z=z), breaks = seq(15,30,1), size = 0.8, colour = "black")+
  geom_point(data = mdol, aes(rtemp, rsal, colour = mdolc, shape = Location), size = 2, alpha = 0.7, stroke = 1.1)+theme_bw()+stellopts+
  scale_y_continuous(breaks = seq(26,38,2))+
  scale_shape_manual(values=c(16, 17, 15, 4, 3, 0))+
  scale_colour_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white", limits = c(1, 1219), trans = "log10")+
  labs(x = expression(paste("Temp. (", degree~C,")")), y = "Salinity", colour = expression(paste('Mean conc.'~'(ind.'~m^{-3},')')))
#ggsave("DolTS-binnedcolorconc-log10.png", dpi = 400)

ggplot()+
  geom_contour(data = sigdat, aes(x, y, z=z), breaks = seq(14,30,1), size = 0.8, colour = "black")+
  geom_point(data = mdol, aes(rtemp, rsal, colour = mdolc, shape = Location, size = nmeas), alpha = 0.7)+theme_bw()+stellopts+
  scale_y_continuous(breaks = seq(26,38,2))+
  scale_colour_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white", limits = c(1, 1219))+
  labs(x = expression(paste("Temp. (", degree~C,")")), y = "Salinity", colour = expression(paste('Conc.'~'(ind.'~m^{-3},')')), size = "Sample size")
#ggsave("DolTS-samplesize.png", dpi = 300)

max(subset(mdol, location == "S. California")$mdolc)
min(mdol$mdolc)

#try some different bins
head(dolto)
dolto$rsal <- round_any(dolto$msal, 0.5, ceiling)
dolto$rtemp <- round_any(dolto$mtemp, 0.5, ceiling)
mdol <- ddply(dolto, .(Location, rsal, rtemp), summarize, mdolc = mean(dolconc), nmeas = length(dolconc))
head(mdol)

ggplot()+
  geom_contour(data = sigdat, aes(x, y, z=z), breaks = seq(12,30,1), size = 0.8, colour = "black")+
  geom_point(data = mdol, aes(rtemp, rsal, colour = mdolc, shape = Location), size = 2, alpha = 0.7, stroke = 1.1)+theme_bw()+stellopts+
  scale_y_continuous(breaks = seq(26,38,2))+
  scale_shape_manual(values=c(16, 17, 15, 4, 3, 0))+
  scale_colour_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white", limits = c(1, 945))+
  labs(x = expression(paste("Temp. (", degree~C,")")), y = "Salinity", colour = expression(paste('Conc.'~'(ind.'~m^{-3},')')))
#ggsave("DolTS-binnedcolorconc.png", dpi = 300)
summary(mdol$mdolc)

#now just look at the data where you have 3 stages classified: nurses, phorozooids, and gonozooids
#Oregon, Northern CA, Gulf of Mexico, Mediterranean
head(orc2019)
head(orc2018)
head(cac2018)
head(cac2019)
head(newfr2)
head(newfr)
head(med1)

or2 <- rbind(orc2019[,2:6], orc2018[,2:6])
or2$Location <- "Oregon"

ca2 <- rbind(cac2019[,2:6], cac2018[,2:6])
ca2$Location <- "N. California"

#buds <- rep(0, nrow(com2))
#gom2 <- data.frame(com2[,3], buds, com2[,c(2,12,4)])
#gom2$Location <- "Gulf of Mexico"
#colnames(gom2) <- colnames(ca2)

gom2 <- rbind(newfr, newfr2)
head(gom2)
gom2m <- gom2[,c(2,4,3,5,7)]
gom2m$Location <- "Gulf of Mexico"

med1m <- med1[,c(2:6)]
med1m$Location <- "Mediterranean"

todol <- rbind(ca2, or2,gom2m, med1m)
todol$percnurs <- todol$nurse/todol$dolconc

ggplot(subset(todol, dolconc >= 5), aes(dolconc, percnurs*100))+geom_point(alpha = 0.2)+geom_smooth(se = FALSE, method = "gam", formula = y ~ s(x, bs = "cs"))+facet_wrap(~Location, scales = "free_x", nrow = 1)+theme_bw()+
#  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent nurses")
#ggsave("PercNursevsTotDolConc-AllAuto.png", dpi = 300)

todol$percbud <-  todol$buds/todol$dolconc

ggplot(subset(todol, dolconc >= 5), aes(dolconc, percbud*100))+geom_point(alpha = 0.2)+geom_smooth(se = FALSE, method = "gam", formula = y ~ s(x, bs = "cs"))+facet_wrap(~Location, scales = "free_x", nrow = 1)+theme_bw()+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent phorozooids")

td3 <- subset(todol, dolconc >= 30) 
head(td3)
td3 <- td3[,c(4,6:8)]
colnames(td3)[3:4] <- c("Nurse", "Phorozooid")

tdm <- melt(td3, id = c("Location", "dolconc"))

ggplot(tdm, aes(dolconc, value))+geom_point(alpha = 0.2)+geom_smooth(method="glm", se=F, method.args = list(family="quasibinomial"))+facet_grid(variable~Location, scales = "free_x")+theme_bw()+
  scale_colour_brewer(palette = "Set1")+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent doliolids belonging to life stage")

ggplot(tdm, aes(dolconc, value*100))+geom_point(alpha = 0.2)+geom_smooth(se = FALSE, method = "gam", formula = y ~ s(x, bs = "cs"), colour = "grey60")+facet_grid(variable~Location, scales = "free_x")+theme_bw()+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent of doliolids belonging to life stage")
#ggsave("PercNursePhorvsTotDolConc-AllAuto-bw.png", dpi = 300)

#do the graph with all 3 life stages
todol$percgon <- todol$sdol/todol$dolconc
td3 <- subset(todol, dolconc >= 15) #15 is pretty good for an accurate estimate
head(td3)
td3 <- td3[,c(4,6:9)]
colnames(td3)[3:5] <- c("Nurse", "Phorozooid", "Gonozooid")

tdm <- melt(td3, id = c("Location", "dolconc"))

ggplot(tdm, aes(dolconc, value))+geom_point(alpha = 0.2)+geom_smooth(method="glm", se=F, method.args = list(family="quasibinomial"))+facet_grid(variable~Location, scales = "free_x")+theme_bw()+
  scale_colour_brewer(palette = "Set1")+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent doliolids belonging to life stage")

ggplot(tdm, aes(dolconc, value, colour = variable))+geom_point(alpha = 0.2)+geom_smooth(method="glm", se=F, method.args = list(family="quasibinomial"))+facet_wrap(~Location, scales = "free_x", nrow = 1)+theme_bw()+
  scale_colour_brewer(palette = "Set1")+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent doliolids belonging to life stage")

#do the graph with all 3 life stages but get rid of extreme values on the high end
pthresh <- .997 #only keep the values less than 99.7 percentile - gets rid of really extreme outliers that will drive a model fit
oqua <- quantile(subset(todol, Location == "Oregon")$dolconc, probs = pthresh)
mqua <- quantile(subset(todol, Location == "Mediterranean")$dolconc, probs = pthresh)
nqua <- quantile(subset(todol, Location == "N. California")$dolconc, probs = pthresh)
gqua <- quantile(subset(todol, Location == "Gulf of Mexico")$dolconc, probs = pthresh)

#limit obs to ones less than 99.5%
medr <- subset(todol, Location == "Mediterranean" & dolconc <= mqua)
gomr <- subset(todol, Location == "Gulf of Mexico" & dolconc <= gqua)
car1 <- subset(todol, Location == "N. California" & dolconc <= nqua)
orer <- subset(todol, Location == "Oregon" & dolconc <= oqua)

todol2 <- rbind(medr, gomr, car1, orer)

td3 <- subset(todol2, dolconc >= 15)#15 is pretty good minimum abundance for an estimate of percent life stage
head(td3)
td3 <- td3[,c(4,6:9)]
colnames(td3)[3:5] <- c("Nurse", "Phorozooid", "Gonozooid")

tdm <- melt(td3, id = c("Location", "dolconc"))

ggplot(tdm, aes(dolconc, value))+geom_point(alpha = 0.1, size = 0.6)+geom_smooth(method="glm", se=F, method.args = list(family="quasibinomial"))+facet_grid(variable~Location, scales = "free_x")+theme_bw()+
  scale_colour_brewer(palette = "Set1")+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Proportion of doliolids belonging to life stage")


ggplot(tdm, aes(dolconc, value, colour = variable))+geom_point(alpha = 0.2)+geom_smooth(method="glm", se=F, method.args = list(family="quasibinomial"))+facet_wrap(~Location, nrow = 1, scales = "free_x")+theme_bw()+
  scale_colour_brewer(palette = "Set1")+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent doliolids belonging to life stage")


dolmin <- 15

#negative coeffieicent means that as the abundance goes up as the porportion is dropping
#comments based on min value of 15

summary(glm(percbud~dolconc, family = "quasibinomial", data = subset(medr, dolconc >= dolmin))) #ns
summary(glm(percnurs ~ dolconc, family = "quasibinomial", data = subset(medr, dolconc >= dolmin))) #highly significant negative
summary(glm(percgon ~ dolconc, family = "quasibinomial", data = subset(medr, dolconc >= dolmin))) #highly significant positive

summary(glm(percbud~dolconc, family = "quasibinomial", data = subset(gomr, dolconc >= dolmin))) #sig negative
summary(glm(percnurs ~ dolconc, family = "quasibinomial", data = subset(gomr, dolconc >= dolmin))) #significant negative
summary(glm(percgon ~ dolconc, family = "quasibinomial", data = subset(gomr, dolconc >= dolmin))) #sig positive

summary(glm(percbud~dolconc, family = "quasibinomial", data = subset(car1, dolconc >= dolmin))) #signifncant positive
summary(glm(percnurs ~ dolconc, family = "quasibinomial", data = subset(car1, dolconc >= dolmin))) #sig positive
summary(glm(percgon ~ dolconc, family = "quasibinomial", data = subset(car1, dolconc >= dolmin))) #significant negative

summary(glm(percbud~dolconc, family = "quasibinomial", data = subset(orer, dolconc >= dolmin))) #highly significant positive
summary(glm(percnurs ~ dolconc, family = "quasibinomial", data = subset(orer, dolconc >= dolmin))) #ns
summary(glm(percgon ~ dolconc, family = "quasibinomial", data = subset(orer, dolconc >= dolmin))) #slight significnat neg


#####binomial results
summary(glm(percbud~dolconc, family = "binomial", data = subset(medr, dolconc >= dolmin))) #ns
summary(glm(percnurs ~ dolconc, family = "binomial", data = subset(medr, dolconc >= dolmin))) #significant negative
summary(glm(percgon ~ dolconc, family = "binomial", data = subset(medr, dolconc >= dolmin))) #significant positive

summary(glm(percbud~dolconc, family = "binomial", data = subset(gomr, dolconc >= dolmin))) #sig negative
summary(glm(percnurs ~ dolconc, family = "binomial", data = subset(gomr, dolconc >= dolmin))) #ns
summary(glm(percgon ~ dolconc, family = "binomial", data = subset(gomr, dolconc >= dolmin))) #sig positive

summary(glm(percbud~dolconc, family = "binomial", data = subset(car1, dolconc >= dolmin))) #ns
summary(glm(percnurs ~ dolconc, family = "binomial", data = subset(car1, dolconc >= dolmin))) #ns
summary(glm(percgon ~ dolconc, family = "binomial", data = subset(car1, dolconc >= dolmin))) #ns

summary(glm(percbud~dolconc, family = "binomial", data = subset(orer, dolconc >= dolmin))) #ns
summary(glm(percnurs ~ dolconc, family = "binomial", data = subset(orer, dolconc >= dolmin))) #ns
summary(glm(percgon ~ dolconc, family = "binomial", data = subset(orer, dolconc >= dolmin))) #slight significnat neg

ggplot(tdm, aes(dolconc, value))+geom_point(alpha = 0.1, size = 0.6)+geom_smooth(method="glm", se=F, method.args = list(family="binomial"))+facet_grid(variable~Location, scales = "free_x")+theme_bw()+
  scale_colour_brewer(palette = "Set1")+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Proportion of doliolids belonging to life stage")

#quasibinomial better for proportional data - input the significance values into the plot
locs <- rep(c("Gulf of Mexico", "Mediterranean", "N. California", "Oregon"), each = 3)
stages <- rep(c("Nurse", "Phorozooid", "Gonozooid"), times = 4)
sigvals <- c(rep("***", 3), "***", "ns", "***", rep("***", 3), "ns", "***", "*")

sigtx <- data.frame(locs, stages, sigvals)
colnames(sigtx)[1:2] <- c("Location", "variable")

ggplot(tdm, aes(dolconc, value))+geom_point(alpha = 0.1, size = 0.6)+geom_smooth(method="glm", se=F, method.args = list(family="quasibinomial"))+
  scale_colour_brewer(palette = "Set1")+
  geom_text(data = sigtx, aes(Inf, .5, label=sigvals), hjust = 2, size = 5)+facet_grid(variable~Location, scales = "free_x")+theme_bw()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Proportion of doliolids belonging to life stage")
#ggsave("PercLifeStage-sig-quasbinom.png", dpi = 400)

#do the same graph with manual nGOM data - just to see how it is different from nGOM- manual is only 1 transect though
com2 <- read.csv("ManualDolEnv.csv", header = TRUE)
head(com2)

com2$percbud <- com2$Phorozooid/com2$totdol
com2$percnurs <- com2$Nurse/com2$totdol
com2 <- com2[, c(13:15)]
colnames(com2)[2:3] <- c("Phorozooid", "Nurse")

cc2 <- melt(com2, id = "totdol")
ggplot(cc2, aes(totdol, value*100))+geom_point(alpha = 0.2)+geom_smooth(se = FALSE, method = "gam", formula = y ~ s(x, bs = "cs"))+facet_grid(variable~., scales = "free_x")+theme_bw()+
  #  scale_x_log10()+
  labs(x = expression(paste('Doliolid abundance'~'(ind.'~m^{-3},')')), y = "Percent doliolids belonging to life stage")
#ggsave("PercNursPhorTotalConc-manual.png", dpi = 400)

#read in data from kelly
load("doliolid_syn_phy_data.R")
ggplot(data.doliolid, aes(ecosystem, -bvf_midp_m))+geom_boxplot()+theme_bw() #where is the stratification max located?

ggplot(data.doliolid, aes(bvf_N2))+geom_histogram(binwidth = .0001)+facet_wrap(~ecosystem)+theme_bw()+xlim(0,.05)
max(data.doliolid$bvf_N2)
data.doliolid[which.max(data.doliolid$bvf_N2),]

ddply(data.doliolid, .(ecosystem), function(maxfinder) {maxfinder[which.max(maxfinder$bvf_N2),]})

#####add the zeros to doliolid abundance and calculate patchiness stats
head(newfr)
rjul <- seq(min(newfr$rjul), max(newfr$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

ttd <- merge(newfr, njul, by = "rjul", all.y = TRUE)
gtdol <- ttd[,c(1,5,7)]

rjul <- seq(min(newfr2$rjul), max(newfr2$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd2 <- merge(newfr2, njul, by = "rjul", all.y = TRUE)
gtdol2 <- ttd2[,c(1,5,7)]

gtd <- rbind(gtdol, gtdol2)
gtd$Location <- "Gulf of Mexico"
gtd[is.na(gtd)] <- 0
mean(gtd$dolconc)
length(gtd$dolconc)

nrow(gtd)
lloyds(gtd$dolconc)
lloyds(sample(gtd$dolconc, nrow(gtd)/5))

#randomly sample 20% of the observations within the gulf data, calculate patchiness, repeat 10,000 times
pstat <- vector(length = 10000)
for(i in 1:length(pstat)){
  pstat[i] <- lloyds(sample(gtd$dolconc, nrow(gtd)/5))
}
pstat <- as.data.frame(pstat, header = FALSE)

head(orc2018)
head(orc2019)
#make a sequence of possible julian times - going from start to end of the transect
rjul <- seq(min(orc2018$rjul), max(orc2018$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

ttd <- merge(orc2018, njul, by = "rjul", all.y = TRUE)
orcdol <- ttd[,c(1,5,7)]

rjul <- seq(min(orc2019$rjul), max(orc2019$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd2 <- merge(orc2019, njul, by = "rjul", all.y = TRUE)
orcdol2 <- ttd2[,c(1,5,7)]

orcd <- rbind(orcdol, orcdol2)
orcd$Location <- "Oregon"

#julian times not represented have no doliolids, and therefore get a zero
orcd[is.na(orcd)] <- 0
mean(orcd$dolconc)
length(orcd$dolconc)

#randomly sample 20% of the observations within the Oregon data, calculate patchiness, repeat 10,000 times
pstat2 <- vector(length = 10000)
for(i in 1:length(pstat2)){
  pstat2[i] <- lloyds(sample(orcd$dolconc, nrow(orcd)/5))
}
pstat2 <- as.data.frame(pstat2, header = FALSE)

#same thing for N. California data - combine first
head(cac2018)
head(cac2019)
rjul <- seq(min(cac2018$rjul), max(cac2018$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

ttd <- merge(cac2018, njul, by = "rjul", all.y = TRUE)
cacdol <- ttd[,c(1,5,7)]

rjul <- seq(min(cac2019$rjul), max(cac2019$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd2 <- merge(cac2019, njul, by = "rjul", all.y = TRUE)
cacdol2 <- ttd2[,c(1,5,7)]

cacd <- rbind(cacdol, cacdol2)
cacd$Location <- "N. California"
cacd[is.na(cacd)] <- 0
mean(cacd$dolconc)
length(cacd$dolconc)

pstat3 <- vector(length = 10000)
for(i in 1:length(pstat3)){
  pstat3[i] <- lloyds(sample(cacd$dolconc, nrow(cacd)/5))
}
pstat3 <- as.data.frame(pstat3, header = FALSE)

#Same thing for the San Diego Data - need to use the date-time ranges since the transects are not complete
#only looked at 1/2 of the "casts" - see methods in Luo et al. 2014 - Marine Ecology Progress Series
head(sd2010)
unique(sd2010$transect)
sd2 <- subset(sd2010, transect == "2")
rjul <- seq(min(sd2$rjul), max(sd2$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

#need to only use the julian times where we got measurements.
sdtimes <- read.csv(file = "dateTime_ranges_transect_2_3.csv", header = TRUE)
head(sdtimes)
sd2t <- subset(sdtimes, transect == "2")

datalist = list()

for(i in 1:nrow(sd2t)){
  mnjul <- subset(njul, rjul >= sd2t$julbeg[i] & rjul <= sd2t$julend[i])
  mnjul$i
  datalist[[i]] <- mnjul
}
nnjul <- do.call(rbind, datalist)

bioenv <- nearphys(sd2$rjul, nnjul$rjul)

rjul2 <- nnjul[bioenv,1]
sd2f <- cbind(rjul2, sd2)
colnames(nnjul)[1] <- "rjul2"

ttd <- merge(sd2f, nnjul, by = "rjul2", all.y = TRUE)

sddol <- ttd[,c(2,4,6)]

sd3 <- subset(sd2010, transect == "3")
sd3$rjul <- ifelse(sd3$rjul < .5, sd3$rjul+1, sd3$rjul)
rjul <- seq(min(sd3$rjul), max(sd3$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

sd3t <- subset(sdtimes, transect == "3")

datalist = list()

for(i in 1:nrow(sd3t)){
  mnjul <- subset(njul, rjul >= sd3t$julbeg[i] & rjul <= sd3t$julend[i])
  mnjul$i
  datalist[[i]] <- mnjul
}
nnjul <- do.call(rbind, datalist)

bioenv <- nearphys(sd3$rjul, nnjul$rjul)

rjul2 <- nnjul[bioenv,1]
sd3f <- cbind(rjul2, sd3)
colnames(nnjul)[1] <- "rjul2"


ttd2 <- merge(sd3f, nnjul, by = "rjul2", all.y = TRUE)
sddol2 <- ttd2[,c(2,4,6)]

sdd <- rbind(sddol, sddol2)
sdd$Location <- "S. California"
sdd[is.na(sdd)] <- 0
mean(sdd$dolconc)
length(sdd$dolconc)
exp(mean(log(sdd$dolconc)))   

pstat4 <- vector(length = 10000)
for(i in 1:length(pstat4)){
  pstat4[i] <- lloyds(sample(sdd$dolconc, nrow(sdd)/5))
}
pstat4 <- as.data.frame(pstat4, header = FALSE)

#same thing for all data from Straits of Florida
head(fl2014)
head(fl2015)
rjul <- seq(min(fl2014$rjul), max(fl2014$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

ttd <- merge(fl2014, njul, by = "rjul", all.y = TRUE)
fldol <- ttd[,c(1,2,4)]

rjul <- seq(min(fl2015$rjul), max(fl2015$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd2 <- merge(fl2015, njul, by = "rjul", all.y = TRUE)
fldol2 <- ttd2[,c(1,2,4)]

fld <- rbind(fldol, fldol2)
fld$Location <- "Florida"
fld[is.na(fld)] <- 0
mean(fld$dolcon)
length(fld$dolcon)

pstat5 <- vector(length = 10000)
for(i in 1:length(pstat5)){
  pstat5[i] <- lloyds(sample(fld$dolconc, nrow(fld)/5))
}
pstat5 <- as.data.frame(pstat5, header = FALSE)

#Same thing for the Mediterranean data - only use data where we have a complete bin sampled.
#Otherwise, Lloyds patchiness index is not valid - see Bez 2000
mdol <- read.csv("medDols_allCols_1mbin.csv", header = TRUE)
head(mdol)
mdol <- subset(mdol, image_vol == .984)
ddply(mdol, .(transect), summarize, mintime = min(mtime, na.rm = TRUE), maxtime = max(mtime, na.rm = TRUE))
lloyds(mdol$dolcon)

pstat6 <- vector(length = 10000)
for(i in 1:length(pstat6)){
  pstat6[i] <- lloyds(sample(mdol$dolcon, nrow(mdol)/5))
}
pstat6 <- as.data.frame(pstat6, header = FALSE)
mean(mdol$dolcon)
length(mdol$dolcon)

pstat$Location <- "Gulf of Mexico"
pstat2$Location <- "Oregon"
colnames(pstat2)[1] <- "pstat"
pstat3$Location <- "N. California"
colnames(pstat3)[1] <- "pstat"
pstat4$Location <- "S. California"
colnames(pstat4)[1] <- "pstat"
pstat5$Location <- "Florida"
colnames(pstat5)[1] <- "pstat"
pstat6$Location <- "Mediterranean"
colnames(pstat6)[1] <- "pstat"

pst <- rbind(pstat, pstat2, pstat3, pstat4, pstat5, pstat6)
quantile(pstat2$pstat, probs = .95)[1]

dolpatch <- ddply(pst, .(Location), summarise, mpatch = mean(pstat), conf97 = quantile(pstat, probs = .975), conf25 = quantile(pstat, probs = .025), nsamp = length(Location))

abund <- c(2.4396, 58.6537, 3.7693, 18.8853, 5.4464, 1.0274)
nsamps <- c(1142, 5737, 10733, 5387, 7625, 2916)
dp2 <- cbind(dolpatch, abund, nsamps)
head(dp2)
#write.csv(dp2, file = "MeanDolPatchAbund.csv", row.names = FALSE)
#read.csv("MeanDolPatchAbund.csv")

ggplot(dp2, aes(Location, mpatch, size = abund))+geom_point()

ggplot(dp2, aes(abund, mpatch, colour = Location))+geom_point()

ggplot()+
  geom_errorbar(data = dp2, aes(abund, ymin = conf25, ymax = conf97))+
  geom_point(data = dp2, aes(abund, mpatch, colour = Location), size = 3)

ggplot()+
  geom_errorbar(data = dp2, aes(Location, ymin = conf25, ymax = conf97), size = 0.8, width = 0.3)+
  geom_point(data = dp2, aes(Location, mpatch, colour = abund), size = 4)+ll+
  theme_bw()+stellopts+theme(axis.text.x = element_text(angle = 90))+
  labs(x = "", y = "Lloyd's patchiness index", color = expression(paste('Mean abundance'~'(ind.'~m^{-3},')')))+
  theme(legend.position = c(.8, .7))
ggsave("LloydsbyLoc.png", dpi = 400)

pst2 <- merge(pst, dp2, by = "Location", all.x = TRUE)

ggplot()+
  geom_boxplot(data = pst2, aes(Location, pstat, fill = abund))+lll+
  theme_bw()+stellopts+theme(axis.text.x = element_text(angle = 90))+
  scale_y_log10(limits = c(1, 1000))+
  labs(x = "", y = "Lloyd's patchiness index", fill = expression(paste('Mean abundance'~'(ind.'~m^{-3},')')))+
  theme(legend.position = c(.2, .7))
#ggsave("LloydsbyLocBoxplot.png", dpi = 400)

#same thing but with life stage specific data only-first do gonos
head(newfr)
rjul <- seq(min(newfr$rjul), max(newfr$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd <- merge(newfr, njul, by = "rjul", all.y = TRUE)

gtdol <- ttd[,c(1:4,7)]
rjul <- seq(min(newfr2$rjul), max(newfr2$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd2 <- merge(newfr2, njul, by = "rjul", all.y = TRUE)
gtdol2 <- ttd2[,c(1:4,7)]

gtd <- rbind(gtdol, gtdol2)
gtd$Location <- "Gulf of Mexico"
gtd[is.na(gtd)] <- 0
mean(gtd$sdol)
mean(gtd$nurse)
mean(gtd$buds)


pstat <- vector(length = 10000)
for(i in 1:length(pstat)){
  pstat[i] <- lloyds(sample(gtd$sdol, nrow(gtd)/5))
}
pstat <- as.data.frame(pstat, header = FALSE)

head(orc2018)
head(orc2019)
rjul <- seq(min(orc2018$rjul), max(orc2018$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

ttd <- merge(orc2018, njul, by = "rjul", all.y = TRUE)
orcdol <- ttd[,c(1:4,7)]

rjul <- seq(min(orc2019$rjul), max(orc2019$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd2 <- merge(orc2019, njul, by = "rjul", all.y = TRUE)
orcdol2 <- ttd2[,c(1:4,7)]

orcd <- rbind(orcdol, orcdol2)
orcd$Location <- "Oregon"
orcd[is.na(orcd)] <- 0
mean(orcd$sdol)
mean(orcd$buds)
mean(orcd$nurse)

pstat2 <- vector(length = 10000)
for(i in 1:length(pstat2)){
  pstat2[i] <- lloyds(sample(orcd$sdol, nrow(orcd)/5))
}
pstat2 <- as.data.frame(pstat2, header = FALSE)

head(cac2018)
head(cac2019)
rjul <- seq(min(cac2018$rjul), max(cac2018$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)

ttd <- merge(cac2018, njul, by = "rjul", all.y = TRUE)
cacdol <- ttd[,c(1:4,7)]

rjul <- seq(min(cac2019$rjul), max(cac2019$rjul), by = 8.1e-05)
njul <- as.data.frame(rjul)
ttd2 <- merge(cac2019, njul, by = "rjul", all.y = TRUE)
cacdol2 <- ttd2[,c(1:4,7)]

cacd <- rbind(cacdol, cacdol2)
cacd$Location <- "N. California"
cacd[is.na(cacd)] <- 0
mean(cacd$sdol)
mean(cacd$buds)
mean(cacd$nurse)

pstat3 <- vector(length = 10000)
for(i in 1:length(pstat3)){
  pstat3[i] <- lloyds(sample(cacd$sdol, nrow(cacd)/5))
}
pstat3 <- as.data.frame(pstat3, header = FALSE)

mdol <- read.csv("medDols_allCols_1mbin.csv", header = TRUE)
head(mdol)
mdol <- subset(mdol, image_vol == .984)

pstat4 <- vector(length = 10000)
for(i in 1:length(pstat4)){
  pstat4[i] <- lloyds(sample(mdol$ndols, nrow(mdol)/5))
}
pstat4 <- as.data.frame(pstat4, header = FALSE)
mean(mdol$ndols)
summary(mdol$nnurse)
mean(mdol$nbuds)
mean(mdol$nnurse)
lloyds(mdol$nbuds)

pstat$Location <- "Gulf of Mexico"
pstat2$Location <- "Oregon"
colnames(pstat2)[1] <- "pstat"
pstat3$Location <- "N. California"
colnames(pstat3)[1] <- "pstat"
pstat4$Location <- "Mediterranean"
colnames(pstat4)[1] <- "pstat"

pst <- rbind(pstat, pstat2, pstat3, pstat4)
quantile(pstat2$pstat, probs = .95)[1]

dolpatch <- ddply(pst, .(Location), summarise, mpatch = mean(pstat), conf97 = quantile(pstat, probs = .975), conf25 = quantile(pstat, probs = .025))

abund <- c(mean(gtd$sdol), mean(mdol$ndols), mean(cacd$sdol), mean(orcd$sdol))
dp2 <- cbind(dolpatch, abund)

###same thing for nurses
pstat <- vector(length = 10000)
for(i in 1:length(pstat)){
  pstat[i] <- lloyds(sample(gtd$nurse, nrow(gtd)/5))
}
pstat <- as.data.frame(pstat, header = FALSE)

pstat2 <- vector(length = 10000)
for(i in 1:length(pstat2)){
  pstat2[i] <- lloyds(sample(orcd$nurse, nrow(orcd)/5))
}
pstat2 <- as.data.frame(pstat2, header = FALSE)

pstat3 <- vector(length = 10000)
for(i in 1:length(pstat3)){
  pstat3[i] <- lloyds(sample(cacd$nurse, nrow(cacd)/5))
}
pstat3 <- as.data.frame(pstat3, header = FALSE)

pstat4 <- vector(length = 10000)
for(i in 1:length(pstat4)){
  pstat4[i] <- lloyds(sample(mdol$nnurse, nrow(mdol)/5))
}
pstat4 <- as.data.frame(pstat4, header = FALSE)

pstat$Location <- "Gulf of Mexico"
pstat2$Location <- "Oregon"
colnames(pstat2)[1] <- "pstat"
pstat3$Location <- "N. California"
colnames(pstat3)[1] <- "pstat"
pstat4$Location <- "Mediterranean"
colnames(pstat4)[1] <- "pstat"

pst2 <- rbind(pstat, pstat2, pstat3, pstat4)
quantile(pstat2$pstat, probs = .95)[1]

dolpatch2 <- ddply(pst2, .(Location), summarise, mpatch = mean(pstat), conf97 = quantile(pstat, probs = .975), conf25 = quantile(pstat, probs = .025))

abund2 <- c(mean(gtd$nurse), mean(mdol$nnurse), mean(cacd$nurse), mean(orcd$nurse))
dp2n <- cbind(dolpatch2, abund2)

####same thing for phoros
pstat <- vector(length = 10000)
for(i in 1:length(pstat)){
  pstat[i] <- lloyds(sample(gtd$buds, nrow(gtd)/5))
}
pstat <- as.data.frame(pstat, header = FALSE)

pstat2 <- vector(length = 10000)
for(i in 1:length(pstat2)){
  pstat2[i] <- lloyds(sample(orcd$buds, nrow(orcd)/5))
}
pstat2 <- as.data.frame(pstat2, header = FALSE)

pstat3 <- vector(length = 10000)
for(i in 1:length(pstat3)){
  pstat3[i] <- lloyds(sample(cacd$buds, nrow(cacd)/5))
}
pstat3 <- as.data.frame(pstat3, header = FALSE)

pstat4 <- vector(length = 10000)
for(i in 1:length(pstat4)){
  pstat4[i] <- lloyds(sample(mdol$nbuds, nrow(mdol)/5))
}
pstat4 <- as.data.frame(pstat4, header = FALSE)

pstat$Location <- "Gulf of Mexico"
pstat2$Location <- "Oregon"
colnames(pstat2)[1] <- "pstat"
pstat3$Location <- "N. California"
colnames(pstat3)[1] <- "pstat"
pstat4$Location <- "Mediterranean"
colnames(pstat4)[1] <- "pstat"

pst3 <- rbind(pstat, pstat2, pstat3, pstat4)
quantile(pstat3$pstat, probs = .95)[1]

dolpatch3 <- ddply(pst3, .(Location), summarise, mpatch = mean(pstat), conf97 = quantile(pstat, probs = .975), conf25 = quantile(pstat, probs = .025))

abund3 <- c(mean(gtd$buds), mean(mdol$nbuds), mean(cacd$buds), mean(orcd$buds))
dp3n <- cbind(dolpatch3, abund3)


pst$lstage <- "Gonozooid"
pst2$lstage <- "Nurse"
pst3$lstage <- "Phorozooid"

psta <- rbind(pst, pst2, pst3)

dp2$lstage <- "Gonozooid"
dp2n$lstage <- "Nurse"
dp3n$lstage <- "Phorozooid"

colnames(dp2n)[5] <- "abund"
colnames(dp3n)[5] <- "abund"

dp2a <- rbind(dp2, dp2n, dp3n)

pst2f <- merge(psta, dp2a, by = c("Location", "lstage"), all.x = TRUE)
max(pst2f$abund)


ggplot()+
  geom_boxplot(data = pst2f, aes(lstage, pstat, fill = abund))+
  scale_fill_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white", limits = c(0.1,59))+
  theme_bw()+stellopts+theme(axis.text.x = element_text(angle = 90))+facet_wrap(~Location, nrow = 1)+
  scale_y_log10(limits = c(1, 1000))+theme(strip.text.x = element_text(size = 14))+
#  theme(legend.position = c(.1, .8))+
  labs(x = "", y = "Lloyd's patchiness index", fill = expression(paste('Mean abund.'~'(ind.'~m^{-3},')')))
#ggsave("LloydsbyLoc-lstage2.png", dpi = 400)

ggplot()+
  geom_boxplot(data = pst2f, aes(lstage, pstat, fill = abund))+
  scale_fill_gradientn(colours=c("blue", "#007dff", "cyan", "#00ff7d", "green", "#7dff00", "yellow", "orange", "red"), na.value="white", limits = c(0.1,59))+
  theme_bw()+stellopts+theme(axis.text.x = element_text(angle = 90))+facet_wrap(~Location, nrow = 1)+
  scale_y_log10(limits = c(1, 1000))+theme(strip.text.x = element_text(size = 14))+
  theme(legend.position = "none")+
  labs(x = "", y = "Lloyd's patchiness index", fill = expression(paste('Mean abund.'~'(ind.'~m^{-3},')')))
#ggsave("LloydsbyLoc-lstage-nl2.png", dpi = 400)

