require(nlme)

# load in data
#####
# please email me if you need the file, you can also load in the .csv
load("/Users/Mark/Downloads/revised_doliolid_syn_phy_data.RData")

# shorten name for convenience
r = rev.doliolid.data 
#####

# check distributions and transform
#####
# check structure and distribution of each entry
str(r$rjul)
hist(r$rjul)
range(r$rjul)

str(r$sdol); str(r$buds); str(r$nurse); str(r$dolconc)
# Fl and SD don't have sdol or buds or nurse

hist(r$dolconc)
hist(log(r$dolconc)) # needs a log-transform

r$dolconc = log(r$dolconc)

str(r$mdepth)
hist(r$mdepth)
hist(log(r$mdepth)) # needs a log-transform

r$mdepth = log(r$mdepth)

str(r$msal)
hist(r$msal) # this is a weird distribution, but just check model diagnostics
# note: model diagnostics for doliolid concentration ended up fine
# this is likely because of adding the random effect of ecosystem-year

str(r$mtemp)
hist(r$mtemp) # this is a weird distribution, but just check model diagnostics

str(r$mfluor)
hist(r$mfluor)

hist(log(r$mfluor)) # needs a log transform

r$mfluor = log(r$mfluor)

str(r$moxy)
hist(r$moxy) # this is a weird distribution, but just check model diagnostics

str(r$mirr)
summary(as.factor(r$ecosystem[which(is.na(r$mirr))]))

# SD doesn't have irradiance

hist(r$mirr) # needs a (1/6) transform

r$mirr = r$mirr^(1/6)

hist(r$mlat) # this is a weird distribution, but just check model diagnostics
hist(r$mlon) # this is a weird distribution, but just check model diagnostics

r$transect = as.factor(r$transect)
r$ecosystem = as.factor(r$ecosystem)

table(r$transect, r$ecosystem)

hist(r$bvf_N2)

plot(sort(r$bvf_N2))

# remove some outliers
r = r[-which(r$bvf_N2==min(r$bvf_N2, na.rm=T)),]

# strat needs a complicated transformation
# basically a log-transform of two very long tails
r$strat.sign = 0
r$strat.sign[which(r$bvf_N2>0)] = 1
r$strat.sign[which(r$bvf_N2<0)] = -1

r$strat = r$bvf_N2
r$strat = abs(r$strat)
r$strat[-which(r$strat==0)] = log(r$strat[-which(r$strat==0)])
r$strat[which(r$strat.sign==-1)] = -r$strat[which(r$strat.sign==-1)]

hist(r$strat)
#####

# deal with transects
#####
# we need to account for some ecosystem-year combinations (ecoyears) having multiple transects
r$ecoyear = paste(r$ecosystem, r$year)
require(piecewiseSEM)

# which ecoyears have multiple transects
table(r$transect, r$ecoyear)

gom = r[which(r$ecoyear=="GOM 2016"),]
sandiego = r[which(r$ecoyear=="SD 2010"),]

# adjust response variables based on their transect within each ecoyear

# first, gom
gom2 = gom

for(i in which(colnames(gom)%in%c("dolconc", "strat", "mfluor", "moxy", "msal", "mtemp", "mirr"))){
  for(j in 1:length(unique(gom$transect))){
    gom2[which(gom$transect==unique(gom$transect)[j]),i] = 
      gom[which(gom$transect==unique(gom$transect)[j]),i] + 
      mean(gom[,i], na.rm=T) - 
      mean(gom[which(gom$transect==unique(gom$transect)[j]),i], na.rm=T)
  }
}

# check that it worked
# should be parallel lines of dots
plot(gom2$dolconc~gom$dolconc)

# next, san diego
sandiego2 = sandiego

# comments as above
for(i in which(colnames(sandiego)%in%c("dolconc", "strat", "mfluor", "moxy", "msal", "mtemp", "mirr"))){
  for(j in 1:length(unique(sandiego$transect))){
    sandiego2[which(sandiego$transect==unique(sandiego$transect)[j]),i] = 
      sandiego[which(sandiego$transect==unique(sandiego$transect)[j]),i] + 
      mean(sandiego[,i], na.rm=T) -
      mean(sandiego[which(sandiego$transect==unique(sandiego$transect)[j]),i], na.rm=T) 
  }
}

# check that it worked
# should be parallel lines of dots
plot(sandiego2$dolconc~sandiego$dolconc)

# replace old data
r[which(r$ecoyear=="GOM 2016"),] = gom2
r[which(r$ecoyear=="SD 2010"),] = sandiego2
#####

# PSEM (multigroup version)
# not currently used in MS but keeping it just in case
#####

# "multigroup version" doesn't include ecoyear in the model, because we need it
# for the post-hoc multigroup() analysis

# mirr has many NAs. what if we ignore irradiance?
# note: the model is just as predictive of dol concentration as a model that includes irradiance

# we need to get rid of Fl 2014 (no oxygen data)
# create ecosystem-year variable
r$ecoyear = paste(r$ecosystem, r$year)

# remove Fl 2014
r4 = r[-which(r$ecoyear=="Fl 2014"),]

# refined PSEM
p4 = psem(
  lm(dolconc ~ mtemp + strat + mdepth + msal + moxy + mfluor, data=r4),
  lm(strat ~ mtemp + msal + mdepth, data=r4),
  lm(mfluor ~ msal + mdepth + mtemp + strat, data=r4),
  lm(moxy ~ mfluor + mtemp + mdepth + msal, data=r4),
  lm(msal ~ mdepth + mtemp, data=r4),
  lm(mtemp ~ mdepth, data=r4),
  data=r4
)

# multigroup analysis to check which paths vary across ecosystems
multigroup(p4, group="ecoyear")
#####

# PSEM (random effect version)
# this generates PSEM "A" in the main text
#####
p4r = psem(
  lme(dolconc ~ mtemp + strat + mdepth + msal + moxy + mfluor,
     random = ~1|ecoyear, data=r4, na.action = na.omit),
  lme(strat ~ mtemp + msal + mdepth,
     random = ~1|ecoyear, data=r4, na.action = na.omit),
  lme(mfluor ~ mdepth + mtemp + strat + msal,
     random = ~1|ecoyear, data=r4, na.action = na.omit),
  lme(moxy ~ mfluor + mtemp + mdepth + msal,
     random = ~1|ecoyear, data=r4, na.action = na.omit),
  lme(msal ~ mtemp + mdepth,
     random = ~1|ecoyear, data=r4, na.action = na.omit),
  lme(mtemp ~ mdepth,
     random = ~1|ecoyear, data=r4, na.action = na.omit),
  #msal %~~% mtemp,
  data=r4
)

AIC(p4r)
summary(p4r)
#####

# ecoyear-specific PSEMs
# these are presented in the supplementary material
# they indirectly create PSEM "B" in the main text

# final Fl 2015
#####
Fl15 = r4[which(r4$ecoyear=="Fl 2015"),]

psem.Fl15 = psem(
  lme(dolconc ~ mdepth + moxy + mtemp,
      random = ~1|ecoyear, data=Fl15, na.action = na.omit),
  lme(strat ~ mdepth,
      random = ~1|ecoyear, data=Fl15, na.action = na.omit),
  lme(mfluor ~ mtemp + msal + mdepth,
      random = ~1|ecoyear, data=Fl15, na.action = na.omit),
  lme(moxy ~ mfluor + mdepth + msal + mtemp + strat,
      random = ~1|ecoyear, data=Fl15, na.action = na.omit),
  lme(msal ~ mdepth,
      random = ~1|ecoyear, data=Fl15, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=Fl15, na.action = na.omit),
  msal %~~% mtemp,
  data=Fl15
)

AIC(psem.Fl15)
summary(psem.Fl15)
#####

# final MED 2013
#####
M13 = r4[which(r4$ecoyear=="MED 2013"),]

psem.M13 = psem(
  lme(dolconc ~ mdepth + moxy + mtemp + msal + mfluor,
      random = ~1|ecoyear, data=M13, na.action = na.omit),
  lme(strat ~ mtemp,
      random = ~1|ecoyear, data=M13, na.action = na.omit),
  lme(mfluor ~ mtemp + msal + strat,
      random = ~1|ecoyear, data=M13, na.action = na.omit),
  lme(moxy ~ mfluor + mdepth + msal + mtemp + strat,
      random = ~1|ecoyear, data=M13, na.action = na.omit),
  lme(msal ~ mdepth,
      random = ~1|ecoyear, data=M13, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=M13, na.action = na.omit),
  msal %~~% mtemp,
  data=M13
)

AIC(psem.M13)
summary(psem.M13)
#####

# final OR 2019
#####
O19 = r4[which(r4$ecoyear=="OR 2019"),]

psem.O19 = psem(
  lme(dolconc ~ mdepth + msal + moxy + mfluor + mtemp + strat,
      random = ~1|ecoyear, data=O19, na.action = na.omit),
  lme(strat ~ msal + mtemp + mdepth,
      random = ~1|ecoyear, data=O19, na.action = na.omit),
  lme(mfluor ~ mtemp + mdepth + msal,
      random = ~1|ecoyear, data=O19, na.action = na.omit),
  lme(moxy ~ mfluor + mdepth + msal + mtemp + strat,
      random = ~1|ecoyear, data=O19, na.action = na.omit),
  lme(msal ~ mdepth,
      random = ~1|ecoyear, data=O19, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=O19, na.action = na.omit),
  msal %~~% mtemp,
  data=O19
)

AIC(psem.O19)
summary(psem.O19)
#####

# final OR 2018
#####
O18 = r4[which(r4$ecoyear=="OR 2018"),]

psem.O18 = psem(
  lme(dolconc ~ mdepth + msal + moxy + mfluor + mtemp,
      random = ~1|ecoyear, data=O18, na.action = na.omit),
  lme(strat ~ msal + mtemp,
      random = ~1|ecoyear, data=O18, na.action = na.omit),
  lme(mfluor ~ mtemp + msal + mdepth,
      random = ~1|ecoyear, data=O18, na.action = na.omit),
  lme(moxy ~ mfluor + mdepth + msal + mtemp,
      random = ~1|ecoyear, data=O18, na.action = na.omit),
  lme(msal ~ mdepth,
      random = ~1|ecoyear, data=O18, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=O18, na.action = na.omit),
  msal %~~% mtemp,
  data=O18
)

AIC(psem.O18)
summary(psem.O18)
#####

# final GOM 2016
#####
G16 = r4[which(r4$ecoyear=="GOM 2016"),]

psem.G16 = psem(
  lme(dolconc ~ mdepth + msal + moxy + mfluor + mtemp,
      random = ~1|ecoyear, data=G16, na.action = na.omit),
  lme(strat ~ msal + mdepth + mtemp,
      random = ~1|ecoyear, data=G16, na.action = na.omit),
  lme(mfluor ~ mtemp + mdepth + strat,
      random = ~1|ecoyear, data=G16, na.action = na.omit),
  lme(moxy ~ mfluor + mdepth + msal + strat + mtemp,
      random = ~1|ecoyear, data=G16, na.action = na.omit),
  lme(msal ~ mdepth,
      random = ~1|ecoyear, data=G16, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=G16, na.action = na.omit),
  msal %~~% mtemp,
  data=G16
)

AIC(psem.G16)
summary(psem.G16)
#####

# final CA 2019
#####
C19 = r4[which(r4$ecoyear=="CA 2019"),]

psem.C19 = psem(
  lme(dolconc ~ mdepth + msal + moxy + mfluor + mtemp + strat,
      random = ~1|ecoyear, data=C19, na.action = na.omit),
  lme(strat ~ msal + mdepth,
      random = ~1|ecoyear, data=C19, na.action = na.omit),
  lme(mfluor ~ mtemp + msal,
      random = ~1|ecoyear, data=C19, na.action = na.omit),
  lme(moxy ~ mfluor + mdepth + msal + strat,
      random = ~1|ecoyear, data=C19, na.action = na.omit),
  lme(msal ~ mdepth,
      random = ~1|ecoyear, data=C19, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=C19, na.action = na.omit),
  msal %~~% mtemp,
  data=C19
)

AIC(psem.C19)
summary(psem.C19)
#####

# final CA 2018
#####
C18 = r4[which(r4$ecoyear=="CA 2018"),]

psem.C18 = psem(
  lme(dolconc ~ mdepth + msal + moxy + mfluor,
      random = ~1|ecoyear, data=C18, na.action = na.omit),
  lme(strat ~ mtemp + msal + mdepth,
      random = ~1|ecoyear, data=C18, na.action = na.omit),
  lme(mfluor ~ mdepth + mtemp + msal + strat,
      random = ~1|ecoyear, data=C18, na.action = na.omit),
  lme(moxy ~ mfluor + mtemp + mdepth + msal,
      random = ~1|ecoyear, data=C18, na.action = na.omit),
  lme(msal ~ mdepth,
      random = ~1|ecoyear, data=C18, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=C18, na.action = na.omit),
  msal %~~% mtemp,
  data=C18
)

AIC(psem.C18)
summary(psem.C18)
#####

# final SD 2010
#####
S10 = r4[which(r4$ecoyear=="SD 2010"),]

psem.S10 = psem(
  lme(dolconc ~ mtemp + mdepth + msal + moxy + mfluor,
      random = ~1|ecoyear, data=S10, na.action = na.omit),
  #lme(strat ~ mtemp, 
      #random = ~1|ecoyear, data=S10, na.action = na.omit),
  lme(mfluor ~ mtemp + msal,
      random = ~1|ecoyear, data=S10, na.action = na.omit),
  lme(moxy ~ mfluor + mtemp + mdepth + msal,
      random = ~1|ecoyear, data=S10, na.action = na.omit),
  #lme(msal ~ mdepth, 
      #random = ~1|ecoyear, data=S10, na.action = na.omit),
  lme(mtemp ~ mdepth,
      random = ~1|ecoyear, data=S10, na.action = na.omit),
  msal %~~% mtemp,
  #msal ~ 1,
  #strat ~ 1,
  data=S10
)

AIC(psem.S10)
summary(psem.S10)
#####


peak.stb = qsm[,which(0.50 < main$RD.r2 & main$RD.r2 < 0.70 &
             0.25 < main$CSR.r2 & main$CSR.r2 > 0.45)]
rowMeans(peak.stb)
